@@ -11,7 +11,7 @@
 	* Free Software Foundation; either version 2 of the License, or (at your    *
 	* option) any later version.                                                *
 	\***************************************************************************/
-	/* $Id: class.bofelamimail.inc.php,v 1.25 2007/02/26 22:22:53 sigurdne Exp $ */
+	/* $Id: class.bofelamimail.inc.php,v 1.27 2007/09/22 14:19:45 sigurdne Exp $ */
 
 	class bofelamimail
 	{
@@ -39,19 +39,21 @@
 		{
 			$this->restoreSessionData();
 			
+			// default mailbox INBOX
+			$this->sessionData['mailbox'] = isset($this->sessionData['mailbox']) && $this->sessionData['mailbox'] ? $this->sessionData['mailbox'] : "INBOX";
+			
 			// set some defaults
-			if(count($this->sessionData) == 0)
+	//		if(count($this->sessionData) == 0)
 			{
 				// this should be under user preferences
 				// sessionData empty
 				// no filter active
-				$this->sessionData['activeFilter']	= "-1";
-				// default mailbox INBOX
-				$this->sessionData['mailbox']		= "INBOX";
+				$this->sessionData['activeFilter']	= isset($this->sessionData['activeFilter']) && $this->sessionData['activeFilter'] ? $this->sessionData['activeFilter'] : "-1";
+		
 				// default start message
-				$this->sessionData['startMessage']	= 1;
+				$this->sessionData['startMessage']	= isset($this->sessionData['startMessage']) && $this->sessionData['startMessage'] ? $this->sessionData['startMessage']: 1;
 				// default mailbox for preferences pages
-				$this->sessionData['preferences']['mailbox']	= "INBOX";
+				$this->sessionData['preferences']['mailbox']	= isset($this->sessionData['preferences']['mailbox']) && $this->sessionData['preferences']['mailbox'] ? $this->sessionData['preferences']['mailbox'] : "INBOX";
 				// default sorting
 				if(!empty($GLOBALS['phpgw_info']['user']['preferences']['felamimail']['sortOrder']))
 				{
@@ -121,6 +123,14 @@
 						$this->mailPreferences['imapPort'],
 						$_folderName);
 					break;
+
+				case "imaptls":
+					$mailboxString = sprintf("{%s:%s/tls/novalidate-cert}%s",
+						$this->mailPreferences['imapServerAddress'],
+						$this->mailPreferences['imapPort'],
+						$_folderName);
+					break;
+
 			}
 
 			return $this->encodeFolderName($mailboxString);
@@ -463,9 +473,7 @@
 				}
 					$folders["$folderNameIMAP"] = $displayName;
 				}
-				#exit;
 				ksort($folders,SORT_STRING);
-				reset($folders);
 				return $folders;
 			}
 			else
@@ -476,13 +484,12 @@
 					$folders['INBOX'] = 'INBOX';
 					return $folders;
 				}
-				return false;
+				return array();
 			}
 		}
 		
 		function getHeaders($_startMessage, $_numberOfMessages, $_sort)
 		{
-
 #			printf ("this->bofelamimail->getHeaders start: %s<br>",date("H:i:s",mktime()));
 
 			$caching = CreateObject('felamimail.bocaching',
@@ -1001,7 +1008,7 @@
 		
 		function parseMessage($_structure, $_partID = '')
 		{
-			#if ($_partID == '') _debug_array($_structure);
+			//if ($_partID == '') _debug_array($_structure);
 			
 			switch ($_structure->type)
 			{
@@ -1015,9 +1022,10 @@
 					$data["name"]		= lang("unknown");
 					if(isset($_structure->parameters) && is_array($_structure->parameters))
 					{
-						for ($lcv = 0; $lcv < count($_structure->parameters); $lcv++)
+						$cnt_params =  count($_structure->parameters);
+						for ($lcv = 0; $lcv < $cnt_params; ++$lcv)
 						{
-							$param = $_structure->parameters[$lcv];
+							$param = $_structure->parameters->$lcv;
 							switch(strtolower($param->attribute))
 							{
 								case 'name':
