@@ -8,7 +8,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package hrm
 	* @subpackage manual
- 	* @version $Id: hook_help.inc.php,v 1.3 2005/11/30 17:07:22 sigurdne Exp $
+ 	* @version $Id: hook_help.inc.php,v 1.4 2007/03/07 10:46:26 sigurdne Exp $
 	*/
 
 
@@ -24,7 +24,7 @@
 	$GLOBALS['phpgw']->help->data[] = array
 	(
 		'text'					=> lang('overview'),
-		'link'					=> $GLOBALS['phpgw']->help->check_help_file('overview.php'),
+		'url'					=> $GLOBALS['phpgw']->help->check_help_file('overview.php'),
 		'lang_link_statustext'	=> lang('overview')
 	);
 
@@ -32,14 +32,14 @@
 	$GLOBALS['phpgw']->help->data[] = array
 	(
 		'text'					=> lang('hrm'),
-		'link'					=> $GLOBALS['phpgw']->help->check_help_file('hrm.php'),
+		'url'					=> $GLOBALS['phpgw']->help->check_help_file('hrm.php'),
 		'lang_link_statustext'	=> lang('hrm')
 	);
 
 	$GLOBALS['phpgw']->help->data[] = array
 	(
 		'text'					=> lang('project'),
-		'link'					=> $GLOBALS['phpgw']->help->check_help_file('project.php'),
+		'url'					=> $GLOBALS['phpgw']->help->check_help_file('project.php'),
 		'lang_link_statustext'	=> lang('project')
 	);
 
