@@ -6,7 +6,7 @@
 	* @license http://www.gnu.org/licenses/lgpl.html GNU Lesser General Public License
 	* @package phpgwapi
 	* @subpackage accounts
-	* @version $Id: class.acl.inc.php,v 1.8 2007/03/28 09:52:36 sigurdne Exp $
+	* @version $Id: class.acl.inc.php,v 1.9 2007/08/14 16:32:01 sigurdne Exp $
 	*/
 
 	/**
@@ -1334,7 +1334,7 @@
 					foreach ( $members as $account_id )
 					{
 						$GLOBALS['phpgw']->shm->delete_key($GLOBALS['phpgw_info']['user']['domain'] . 'acl_data_groups_' . $account_id);
-						$GLOBALS['phpgw']->shm->delete_key($GLOBALS['phpgw_info']['user']['domain'] . 'acl_data_accounts_' . $ccount_id);
+						$GLOBALS['phpgw']->shm->delete_key($GLOBALS['phpgw_info']['user']['domain'] . 'acl_data_accounts_' . $account_id);
 						$GLOBALS['phpgw']->shm->delete_key($GLOBALS['phpgw_info']['user']['domain'] . 'acl_data_both_' . $account_id);
 					}
 				}
