@@ -8,7 +8,7 @@
 	* @license http://www.fsf.org/licenses/lgpl.html GNU Lesser General Public License
 	* @package phpgwapi
 	* @subpackage vfs
-	* @version $Id: class.vfs_sql.inc.php,v 1.2 2007/02/06 12:42:18 sigurdne Exp $
+	* @version $Id: class.vfs_sql.inc.php,v 1.3 2007/05/11 12:51:35 sigurdne Exp $
 	*/
 
 	/**
@@ -1992,7 +1992,7 @@
 			reset ($this->attributes);
 			while (list ($num, $attribute) = each ($this->attributes))
 			{
-				if (isset ($data['attributes'][$attribute]))
+				if (isset ($data['attributes'][$attribute]) && $data['attributes'][$attribute])
 				{
 					$$attribute = $data['attributes'][$attribute];
 
