@@ -8,7 +8,7 @@
 	* @license http://www.fsf.org/licenses/lgpl.html GNU Lesser General Public License
 	* @package phpgwapi
 	* @subpackage utilities
-	* @version $Id: functions.inc.php,v 1.5 2007/02/25 16:13:08 sigurdne Exp $
+	* @version $Id: functions.inc.php,v 1.9 2007/03/20 08:37:15 sigurdne Exp $
 	*/
 	
 	
@@ -292,7 +292,7 @@
 	}
 	else
 	{
-		error_reporting(E_ERROR | E_WARNING | E_PARSE);
+		error_reporting(E_USER_ERROR | E_ERROR | E_WARNING | E_PARSE);
 	}
 
 	function clean_vars($vars, $safe_redirect = True)
@@ -391,20 +391,21 @@
 	 /************************************************************************\
 	 * Load up the main instance of the db class.                             *
 	 \************************************************************************/
-	$GLOBALS['phpgw']->db                = createObject('phpgwapi.db');
-	$GLOBALS['phpgw']->db->Debug         = $GLOBALS['phpgw']->debug ? 1 : 0;
-	$GLOBALS['phpgw']->db->Halt_On_Error = 'no';
-	$GLOBALS['phpgw']->adodb             =& $GLOBALS['phpgw']->db->adodb; //Reference
-	
-	@$GLOBALS['phpgw']->adodb->connect($GLOBALS['phpgw_info']['server']['db_host'],
-									   $GLOBALS['phpgw_info']['server']['db_user'],
-									   $GLOBALS['phpgw_info']['server']['db_pass'],
-									   $GLOBALS['phpgw_info']['server']['db_name']
-									  );
-	if(!$GLOBALS['phpgw']->adodb->ErrorNo())
+
+	if($GLOBALS['phpgw_info']['server']['db_abstraction'] == 'phplib')
 	{
-		$GLOBALS['phpgw']->adodb->query('select count(config_name) from phpgw_config');
-		if($GLOBALS['phpgw']->adodb->ErrorNo())
+//---------test phplib
+		$GLOBALS['phpgw']->db           = createObject('phpgwapi.db');
+		$GLOBALS['phpgw']->db->Debug    = $GLOBALS['phpgw']->debug ? 1 : 0;
+		$GLOBALS['phpgw']->db->Host     = $GLOBALS['phpgw_info']['server']['db_host'];
+		$GLOBALS['phpgw']->db->Type     = $GLOBALS['phpgw_info']['server']['db_type'];
+		$GLOBALS['phpgw']->db->Database = $GLOBALS['phpgw_info']['server']['db_name'];
+		$GLOBALS['phpgw']->db->User     = $GLOBALS['phpgw_info']['server']['db_user'];
+		$GLOBALS['phpgw']->db->Password = $GLOBALS['phpgw_info']['server']['db_pass'];
+
+		$GLOBALS['phpgw']->db->Halt_On_Error = 'no';
+		@$GLOBALS['phpgw']->db->query("select count(config_name) from phpgw_config");
+		if (! @$GLOBALS['phpgw']->db->next_record())
 		{
 			$setup_dir = ereg_replace($_SERVER['PHP_SELF'],'index.php','setup/');
 			echo '<center><b>Fatal Error:</b> It appears that you have not created the database tables for '
@@ -414,10 +415,35 @@
 	}
 	else
 	{
-		$setup_dir = ereg_replace($_SERVER['PHP_SELF'],'index.php','setup/');
-		echo '<center><b>Fatal Error:</b> Unable to connect to database server '
-		.'Click <a href="' . $setup_dir . '">here</a> to run setup.</center>';
-		exit;
+		$GLOBALS['phpgw']->db                = createObject('phpgwapi.db');
+		$GLOBALS['phpgw']->db->Debug         = $GLOBALS['phpgw']->debug ? 1 : 0;
+		$GLOBALS['phpgw']->db->Halt_On_Error = 'no';
+
+		$GLOBALS['phpgw']->db->Host     	= $GLOBALS['phpgw_info']['server']['db_host'];
+		$GLOBALS['phpgw']->db->Type     	= $GLOBALS['phpgw_info']['server']['db_type'];
+		$GLOBALS['phpgw']->db->Database 	= $GLOBALS['phpgw_info']['server']['db_name'];
+		$GLOBALS['phpgw']->db->User     	= $GLOBALS['phpgw_info']['server']['db_user'];
+		$GLOBALS['phpgw']->db->Password 	= $GLOBALS['phpgw_info']['server']['db_pass'];
+		$GLOBALS['phpgw']->db->connect();
+
+		if(!$GLOBALS['phpgw']->db->adodb->ErrorNo())
+		{
+			$GLOBALS['phpgw']->db->query('select count(config_name) from phpgw_config');
+			if($GLOBALS['phpgw']->db->adodb->ErrorNo())
+			{
+				$setup_dir = ereg_replace($_SERVER['PHP_SELF'],'index.php','setup/');
+				echo '<center><b>Fatal Error:</b> It appears that you have not created the database tables for '
+				.'phpGroupWare.  Click <a href="' . $setup_dir . '">here</a> to run setup.</center>';
+				exit;
+			}
+		}
+		else
+		{
+			$setup_dir = ereg_replace($_SERVER['PHP_SELF'],'index.php','setup/');
+			echo '<center><b>Fatal Error:</b> Unable to connect to database server '
+			.'Click <a href="' . $setup_dir . '">here</a> to run setup.</center>';
+			exit;
+		}
 	}
 	$GLOBALS['phpgw']->db->Halt_On_Error = 'yes';
 
