@@ -5,7 +5,7 @@
 	* @license http://www.gnu.org/licenses/gpl.html GNU General Public License
 	* @package phpgwapi
 	* @subpackage setup
-	* @version $Id: tables_update.inc.php,v 1.11 2007/05/21 11:58:31 sigurdne Exp $
+	* @version $Id: tables_update.inc.php,v 1.12 2007/09/24 13:19:09 sigurdne Exp $
 	* @internal $Source: /sources/fmsystem/phpgwapi/setup/tables_update.inc.php,v $
 	*/
 
@@ -1647,4 +1647,15 @@
 		$GLOBALS['setup_info']['phpgwapi']['currentver'] = '0.9.17.002';		
 		return $GLOBALS['setup_info']['phpgwapi']['currentver'];
 	}
+
+	/**
+	* Update phpgwapi version from 0.9.17.002 to 0.9.17.003
+	*/
+
+	$test[] = '0.9.17.002';
+	function phpgwapi_upgrade0_9_17_002()
+	{
+		$GLOBALS['setup_info']['phpgwapi']['currentver'] = '0.9.17.003';		
+		return $GLOBALS['setup_info']['phpgwapi']['currentver'];
+	}
 ?>
