@@ -6,7 +6,7 @@
 	* @copyright Copyright (C) 2000-2006 Free Software Foundation, Inc. http://www.fsf.org/
 	* @license http://www.gnu.org/licenses/gpl.html GNU General Public License
 	* @package projects
-	* @version $Id: class.soconfig.inc.php,v 1.29 2006/12/05 19:40:45 sigurdne Exp $
+	* @version $Id: class.soconfig.inc.php,v 1.30 2007/09/05 11:45:29 sigurdne Exp $
 	* $Source: /sources/phpgroupware/projects/inc/class.soconfig.inc.php,v $
 	*/
 
@@ -552,8 +552,8 @@
 		{
 			$start		= intval($values['start']);
 			$limit		= (isset($values['limit'])?$values['limit']:false);
-			$sort		= (isset($values['sort'])?$values['sort']:'ASC');
-			$order		= (isset($values['order'])?$values['order']:'sdate');
+			$sort		= (isset($values['sort']) && $values['sort'] ? $values['sort']:'ASC');
+			$order		= (isset($values['order']) && $values['order'] ? $values['order']:'sdate');
 			$query		= $this->db->db_addslashes($values['query']);
 			$account_id	= intval($values['account_id']);
 			$id			= intval($values['id']);
