@@ -6,7 +6,7 @@
 	* @copyright Copyright (C) 2000-2006 Free Software Foundation, Inc. http://www.fsf.org/
 	* @license http://www.gnu.org/licenses/gpl.html GNU General Public License
 	* @package projects
-	* @version $Id: class.soprojects.inc.php,v 1.119 2006/12/05 19:40:45 sigurdne Exp $
+	* @version $Id: class.soprojects.inc.php,v 1.120 2007/09/05 11:45:29 sigurdne Exp $
 	* $Source: /sources/phpgroupware/projects/inc/class.soprojects.inc.php,v $
 	*/
 
@@ -1522,12 +1522,12 @@
 
 		function plan_bottom_up_set_job_setting($main_project_id, $plan_bottom_up)
 		{
-			$this->db->query('UPDATE phpgw_p_projects SET plan_bottom_up="' . $plan_bottom_up . '" WHERE main=' . $main_project_id, __LINE__,__FILE__);
+			$this->db->query("UPDATE phpgw_p_projects SET plan_bottom_up='" . $plan_bottom_up . "' WHERE main=" . $main_project_id, __LINE__,__FILE__);
 		}
 		
 		function direct_work_set_job_setting($main_project_id, $direct_work)
 		{
-			$this->db->query('UPDATE phpgw_p_projects SET direct_work="' . $direct_work . '" WHERE main=' . $main_project_id, __LINE__,__FILE__);
+			$this->db->query("UPDATE phpgw_p_projects SET direct_work='" . $direct_work . "' WHERE main=" . $main_project_id, __LINE__,__FILE__);
 		}
 
 		function get_projects_tree($mainProject = null, $fields = array('project_id', 'parent', 'title', 'p_number', 'direct_work', 'end_date', 'customer_org', 'status'), $employee=-1)
