@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage core
- 	* @version $Id: class.bocommon.inc.php,v 1.66 2007/03/22 10:35:27 sigurdne Exp $
+ 	* @version $Id: class.bocommon.inc.php,v 1.67 2007/08/21 12:26:04 sigurdne Exp $
 	*/
 
 	/**
@@ -238,11 +238,14 @@
 					$output_list[$j]['id'] = $entry['id'];
 					$output_list[$j]['name'] = $entry['name'];
 
-					for ($i=0;$i<count($selected);$i++)
+					if(isset($selected) && is_array($selected))
 					{
-						if($selected[$i] == $entry['id'])
+						for ($i=0;$i<count($selected);$i++)
 						{
-							$output_list[$j]['selected'] = 'selected';
+							if($selected[$i] == $entry['id'])
+							{
+								$output_list[$j]['selected'] = 'selected';
+							}
 						}
 					}
 					$j++;
