@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage entity
- 	* @version $Id: class.boentity.inc.php,v 1.27 2007/01/26 14:53:46 sigurdne Exp $
+ 	* @version $Id: class.boentity.inc.php,v 1.30 2007/09/21 19:36:38 sigurdne Exp $
 	*/
 
 	/**
@@ -102,7 +102,7 @@
 
 			$this->soadmin_entity 	= CreateObject($this->currentapp.'.soadmin_entity',$entity_id,$cat_id);
 			$this->so 		= CreateObject($this->currentapp.'.soentity',$entity_id,$cat_id);
-			$this->category_name	= $this->soadmin_entity->category_name;
+			$this->category_name	= isset($this->soadmin_entity->category_name) ? $this->soadmin_entity->category_name : '';
 
 			if ($start)
 			{
@@ -193,7 +193,6 @@
 
 			$columns = $soadmin_entity->read_attrib(array('entity_id'=>$entity_id,'cat_id'=>$cat_id,'allrows'=>$allrows,'filter_list' =>true));
 			$column_list=$this->bocommon->select_multi_list($selected,$columns);
-
 			return $column_list;
 		}
 
