@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage location
- 	* @version $Id: class.bolocation.inc.php,v 1.32 2007/03/16 14:31:10 sigurdne Exp $
+ 	* @version $Id: class.bolocation.inc.php,v 1.33 2007/09/21 19:28:56 sigurdne Exp $
 	*/
 
 	/**
@@ -178,6 +178,19 @@
 			}
 		}
 
+		function column_list($selected='',$type_id='',$allrows='')
+		{
+			$soadmin_location	= CreateObject($this->currentapp.'.soadmin_location');
+
+			if(!$selected)
+			{
+				$selected=$GLOBALS['phpgw_info']['user']['preferences'][$this->currentapp]["location_columns_" . $this->type_id];
+			}
+
+			$columns = $soadmin_location->read_attrib(array('type_id'=>$type_id,'allrows'=>$allrows,'filter_list' =>true));
+			$column_list=$this->bocommon->select_multi_list($selected,$columns);
+			return $column_list;
+		}
 
 		function select_status_list($format='',$selected='')
 		{
