@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage project
- 	* @version $Id: class.boproject.inc.php,v 1.22 2007/02/20 22:22:20 sigurdne Exp $
+ 	* @version $Id: class.boproject.inc.php,v 1.24 2007/03/20 12:57:35 sigurdne Exp $
 	*/
 
 	/**
@@ -250,7 +250,7 @@
 			$project				= $this->so->read_single($project_id);
 			$dateformat				= $GLOBALS['phpgw_info']['user']['preferences']['common']['dateformat'];
 			$project['start_date']			= $GLOBALS['phpgw']->common->show_date($project['start_date'],$dateformat);
-			$project['end_date']			= $GLOBALS['phpgw']->common->show_date($project['end_date'],$dateformat);
+			$project['end_date']			= isset($project['end_date']) && $project['end_date'] ? $GLOBALS['phpgw']->common->show_date($project['end_date'],$dateformat) : '';
 			$workorder_data				= $this->so->project_workorder_data($project_id);
 
 			$sum_workorder_budget = 0;
@@ -269,6 +269,7 @@
 				$project['workorder_budget'][$i]['budget']=number_format($workorder_data[$i]['budget'], 2, ',', '');
 				$project['workorder_budget'][$i]['calculation']=number_format($workorder_data[$i]['calculation']*$tax, 2, ',', '');
 				$project['workorder_budget'][$i]['charge_tenant'] = $workorder_data[$i]['charge_tenant'];
+				$project['workorder_budget'][$i]['status'] = $workorder_data[$i]['status'];
 				$vendor	= $contacts->read_single(array('actor_id'=>(int)$workorder_data[$i]['vendor_id']));
 				if(is_array($vendor))
 				{
@@ -332,7 +333,7 @@
 			$project						= $this->so->read_single($project_id);
 			$dateformat						= $GLOBALS['phpgw_info']['user']['preferences']['common']['dateformat'];
 			$project['start_date']			= $GLOBALS['phpgw']->common->show_date($project['start_date'],$dateformat);
-			$project['end_date']			= $GLOBALS['phpgw']->common->show_date($project['end_date'],$dateformat);
+			$project['end_date']			= isset($project['end_date']) && $project['end_date'] ? $GLOBALS['phpgw']->common->show_date($project['end_date'],$dateformat) : '';
 
 			if($project['location_code'])
 			{
@@ -454,7 +455,7 @@
 			$end_date	= $this->bocommon->date_array($project['end_date']);
 
 			$project['start_date']	= mktime (2,0,0,$start_date['month'],$start_date['day'],$start_date['year']);
-			$project['end_date']	= mktime (2,0,0,$end_date['month'],$end_date['day'],$end_date['year']);
+			$project['end_date']	= $end_date ? mktime (2,0,0,$end_date['month'],$end_date['day'],$end_date['year']) : '';
 
 
 			if ($action=='edit')
