@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage agreement
- 	* @version $Id: class.bos_agreement.inc.php,v 1.15 2007/01/26 14:53:46 sigurdne Exp $
+ 	* @version $Id: class.bos_agreement.inc.php,v 1.16 2007/08/12 21:25:10 sigurdne Exp $
 	*/
 
 	/**
@@ -682,6 +682,22 @@
 			return $receipt;
 		}
 
+		function read_attrib_history($data)
+		{
+		//	_debug_array($data);
+			$historylog = CreateObject($this->currentapp.'.historylog','s_agreement');
+			$history_values = $historylog->return_array(array(),array('SO'),'history_timestamp','ASC',$data['id'],$data['attrib_id'],$data['item_id']);
+			$this->total_records = count($history_values);
+		//	_debug_array($history_values);
+			return $history_values;
+		}
+
+		function delete_history_item($data)
+		{
+			$historylog = CreateObject($this->currentapp.'.historylog','s_agreement');
+			$historylog->delete_single_record($data['history_id']);
+		}
+
 
 	}
 ?>
