@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage helpdesk
- 	* @version $Id: class.botts.inc.php,v 1.34 2007/05/19 20:52:10 sigurdne Exp $
+ 	* @version $Id: class.botts.inc.php,v 1.37 2007/08/24 13:59:23 sigurdne Exp $
 	*/
 
 	/**
@@ -197,10 +197,12 @@
 					break;
 			}
 
-			$filters[0]['id']='closed';
-			$filters[0]['name']=lang('Closed');
-			$filters[1]['id']='all';
-			$filters[1]['name']=lang('All');
+			$filters[0]['id']='progress';
+			$filters[0]['name']=lang('In progress');
+			$filters[1]['id']='closed';
+			$filters[1]['name']=lang('Closed');
+			$filters[2]['id']='all';
+			$filters[2]['name']=lang('All');
 
 			return $this->bocommon->select_list($selected,$filters);
 		}
@@ -212,6 +214,8 @@
 			$filters[0]['name']=lang('Closed');
 			$filters[1]['id']='O';
 			$filters[1]['name']=lang('Open');
+			$filters[2]['id']='I';
+			$filters[2]['name']=lang('In progress');
 
 			return $this->bocommon->select_list($selected,$filters);
 		}
@@ -390,7 +394,8 @@
 				'S' => 'Subject changed',
 				'B' => 'Billing rate',
 				'H' => 'Billing hours',
-				'F' => 'finnish date'
+				'F' => 'finnish date',
+				'I' => 'In progress'
 			);
 
 			$ticket['status_name'] = lang($status_text[$ticket['status']]);
@@ -466,12 +471,17 @@
 					case 'B': $type = lang('Billable rate changed'); break;
 					case 'F': $type = lang('finnish date changed'); break;
 					case 'IF': $type = lang('Initial finnish date'); break;
+					case 'I': $type = lang('Status changed'); break;
 					default: break;
 				}
 
-				if($value['new_value']=='O'){$value['new_value']=lang('Opened');}
-				if($value['new_value']=='X'){$value['new_value']=lang('Closed');}
-
+				switch ($value['status'])
+				{
+					case 'O': $value['new_value']=lang('Opened'); break;
+					case 'X': $value['new_value']=lang('Closed'); break;
+					case 'I': $value['new_value']=lang('In Progress'); break; //initiated		
+					default: break;
+				}
 
 				$record_history[$i]['value_action']	= $type?$type:'';
 				unset($type);
@@ -506,7 +516,6 @@
 
 				$i++;
 			}
-
 			return (isset($record_history)?$record_history:'');
 		}
 
@@ -610,7 +619,8 @@
 				'S' => 'Subject changed',
 				'B' => 'Billing rate',
 				'H' => 'Billing hours',
-				'F' => 'finnish date changed'
+				'F' => 'finnish date changed',
+				'I'=> 'Status changed'
 			);
 
 
@@ -800,40 +810,11 @@
 			return $receipt;
 		}
 
-
 		function delete($id)
 		{
 			$this->so->delete($id);
 		}
 
-		function create_home_dir($receipt='')
-		{
-			if(!$this->vfs->file_exists(array(
-					'string' => $this->fakebase. SEP . 'fmticket',
-					'relatives' => Array(RELATIVE_NONE)
-				)))
-			{
-				$this->vfs->override_acl = 1;
-
-				if(!$this->vfs->mkdir (array(
-				     'string' => $this->fakebase. SEP . 'fmticket',
-				     'relatives' => array(
-				          RELATIVE_NONE
-				     )
-				)))
-				{
-					$receipt['error'][]=array('msg'=>lang('failed to create directory') . ' :'. $this->fakebase. SEP . 'fmticket');
-				}
-				else
-				{
-					$receipt['message'][]=array('msg'=>lang('directory created') . ' :'. $this->fakebase. SEP. 'fmticket');
-				}
-				$this->vfs->override_acl = 0;
-			}
-
-			return $receipt;
-		}
-
 		function create_document_dir($id='')
 		{
 			if(!$this->vfs->file_exists(array(
