@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage core
- 	* @version $Id: class.historylog.inc.php,v 1.15 2007/03/16 08:57:05 sigurdne Exp $
+ 	* @version $Id: class.historylog.inc.php,v 1.19 2007/08/13 06:31:30 sigurdne Exp $
 	*/
 
 	/**
@@ -37,6 +37,8 @@
 		var $db;
 		var $appname;
 		var $table;
+		var $attrib_id_field = '';
+		var $detail_id_field = '';
 		var $types = array(
 			'C' => 'Created',
 			'D' => 'Deleted',
@@ -85,6 +87,12 @@
 					break;
 				case 'entity':
 					$this->table='fm_entity_history';
+					$this->attrib_id_field = ',history_attrib_id';
+					break;
+				case 's_agreement':
+					$this->table='fm_s_agreement_history';
+					$this->attrib_id_field = ',history_attrib_id';
+					$this->detail_id_field = ',history_detail_id';
 					break;
 			}
 
@@ -97,7 +105,7 @@
 		{
 			if($attrib_id)
 			{
-				$attrib_id_condition = "and history_entity_attrib_id = $attrib_id";
+				$attrib_id_condition = "and history_attrib_id = $attrib_id";
 			}
 
 			$this->db->query("delete from $this->table where history_record_id='$record_id' and "
@@ -110,20 +118,13 @@
 		}
 
 
-		function add($status,$record_id,$new_value,$old_value ='',$attrib_id='', $date='')
+		function add($status,$record_id,$new_value,$old_value ='',$attrib_id='', $date='',$detail_id='')
 		{
+			$attrib_id_field = $this->attrib_id_field;
+			$attrib_id_value = (isset($attrib_id) && $attrib_id ? ",$attrib_id" : '');
+			$detail_id_field = $this->detail_id_field;
+			$detail_id_value = (isset($detail_id) && $detail_id ? ",$detail_id" : '');
 
-			if($attrib_id)
-			{
-				$attrib_id_field = ',history_entity_attrib_id';
-				$attrib_id_value = ",$attrib_id";			
-			}
-			else
-			{
-				$attrib_id_field = '';
-				$attrib_id_value = '';
-			}
-			
 			if($date)
 			{
 				$timestamp = $this->db->to_timestamp($date);
@@ -132,17 +133,17 @@
 			{
 				$timestamp = $this->db->to_timestamp(time());
 			}
-			
+
 			$this->db->query("insert into $this->table (history_record_id,"
-				. "history_appname,history_owner,history_status,history_new_value,history_timestamp $attrib_id_field) "
+				. "history_appname,history_owner,history_status,history_new_value,history_timestamp $attrib_id_field $detail_id_field) "
 				. "values ('$record_id','" . $this->appname . "','"
 				. $this->account . "','$status','"
 				. $this->db->db_addslashes($new_value) . "','" . $timestamp
-				. "' $attrib_id_value )",__LINE__,__FILE__);
+				. "' $attrib_id_value $detail_id_value)",__LINE__,__FILE__);
 		}
 
 		// array $filter_out
-		function return_array($filter_out,$only_show,$_orderby = '',$sort = '', $record_id,$attrib_id='')
+		function return_array($filter_out,$only_show,$_orderby = '',$sort = '', $record_id,$attrib_id='',$detail_id='')
 		{
 
 			if (! $sort || ! $_orderby)
@@ -167,7 +168,12 @@
 
 			if($attrib_id)
 			{
-				$filter .= "and history_entity_attrib_id = $attrib_id";
+				$filter .= " and history_attrib_id = $attrib_id";
+			}
+
+			if($detail_id)
+			{
+				$filter .= " and history_detail_id = $detail_id";
 			}
 
 			while (is_array($only_show) && list(,$_filter) = each($only_show))
