@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage admin
- 	* @version $Id: class.soadmin_entity.inc.php,v 1.30 2007/01/26 14:53:46 sigurdne Exp $
+ 	* @version $Id: class.soadmin_entity.inc.php,v 1.32 2007/08/31 06:48:06 sigurdne Exp $
 	*/
 
 	/**
@@ -122,14 +122,7 @@
 		{
 			if(is_array($data))
 			{
-				if ($data['start'])
-				{
-					$start=$data['start'];
-				}
-				else
-				{
-					$start=0;
-				}
+				$start = (isset($data['start'])&& $data['start'] ? $data['start'] : 0);
 				$query = (isset($data['query'])?$data['query']:'');
 				$sort = (isset($data['sort'])?$data['sort']:'DESC');
 				$order = (isset($data['order'])?$data['order']:'');
@@ -919,7 +912,7 @@
 		function read_attrib_choice($entity_id,$cat_id,$attrib_id)
 		{
 			$choice_table = 'fm_entity_choice';
-			$sql = "SELECT * FROM $choice_table WHERE entity_id=$entity_id AND cat_id=$cat_id AND attrib_id=$attrib_id";
+			$sql = "SELECT * FROM $choice_table WHERE entity_id=$entity_id AND cat_id=$cat_id AND attrib_id=$attrib_id ORDER BY id";
 			$this->db->query($sql,__LINE__,__FILE__);
 
 			while ($this->db->next_record())
