@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage document
- 	* @version $Id: class.sodocument.inc.php,v 1.14 2007/01/26 14:53:46 sigurdne Exp $
+ 	* @version $Id: class.sodocument.inc.php,v 1.15 2007/08/21 12:26:04 sigurdne Exp $
 	*/
 
 	/**
@@ -118,9 +118,10 @@
 
 				$cols = $document_table . '.location_code';
 				$cols_return[] = 'location_code';
-
-//				$cols .= ",$document_table.id as document_id";
-//				$cols_return[] 				= 'document_id';
+	
+				$uicols = array();
+				$joinmethod = '';
+				$paranthesis = '';
 
 				if ($entity_id)
 				{
