@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage entity
- 	* @version $Id: class.soentity.inc.php,v 1.33 2007/01/26 14:53:46 sigurdne Exp $
+ 	* @version $Id: class.soentity.inc.php,v 1.34 2007/05/08 09:11:45 sigurdne Exp $
 	*/
 
 	/**
@@ -305,7 +305,7 @@
 				{
 					$query = ereg_replace("'",'',$query);
 					$query = ereg_replace('"','',$query);
-					$filtermethod .= " $where ( $entity_table.location_code $this->like '%$query%' OR $entity_table.num $this->like '%$query%'  OR loc1_name $this->like '%$query%' OR address $this->like '%$query%')";
+					$filtermethod .= " $where ( $entity_table.location_code $this->like '%$query%' OR $entity_table.num $this->like '%$query%' OR address $this->like '%$query%')";
 					$where= 'OR';
 
 					$this->db->query("SELECT * FROM fm_entity_attribute where search='1' AND entity_id= $entity_id AND cat_id = $cat_id");
