@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage eco
- 	* @version $Id: class.soinvoice.inc.php,v 1.32 2007/01/26 14:53:46 sigurdne Exp $
+ 	* @version $Id: class.soinvoice.inc.php,v 1.33 2007/03/22 10:35:28 sigurdne Exp $
 	*/
 
 	/**
@@ -922,33 +922,6 @@
 			return $tax_code_list;
 		}
 
-		function get_invoice_user_list()
-		{
-
-			$sql = "SELECT * FROM phpgw_acl $this->join phpgw_accounts on phpgw_accounts.account_id=phpgw_acl.acl_account where acl_location ='.invoice' and account_type='u' order by account_lastname";
-			$this->db->query($sql,__LINE__,__FILE__);
-
-			$employees[] = Array(
-				'account_lid'       => 'all',
-				'account_lastname'  => lang('All')
-			);
-
-			while ($this->db->next_record())
-			{
-				$employees[] = Array(
-					'account_id'        => $this->db->f('account_id'),
-					'account_lid'       => $this->db->f('account_lid'),
-					'account_type'      => $this->db->f('account_type'),
-					'account_firstname' => $this->db->f('account_firstname'),
-					'account_lastname'  => $this->db->f('account_lastname'),
-					'account_status'    => $this->db->f('account_status'),
-					'account_expires'   => $this->db->f('account_expires')
-				);
-			}
-//_debug_array($employees);
-			return $employees;
-		}
-
 		function select_account_class()
 		{
 			$sql = "SELECT id from fm_b_account_category order by id";
