@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage project
- 	* @version $Id: class.sorequest.inc.php,v 1.21 2007/01/26 14:53:47 sigurdne Exp $
+ 	* @version $Id: class.sorequest.inc.php,v 1.22 2007/09/10 14:49:42 sigurdne Exp $
 	*/
 
 	/**
@@ -115,6 +115,8 @@
 					$score = $this->db->f('score');
 					$this->db->query("UPDATE fm_request SET score = $score WHERE id = $id",__LINE__,__FILE__);
 				}
+				
+				$this->db->query("UPDATE fm_request SET score = score +10000 WHERE id = $id AND authorities_demands = 1",__LINE__,__FILE__);
 			}
 		}
 
@@ -581,7 +583,6 @@
 				$vals	= "," . implode(",",$vals);
 			}
 
-//_debug_array($vals);
 			if($request['street_name'])
 			{
 				$address[]= $request['street_name'];
@@ -609,7 +610,8 @@
 				'descr'			=> $request['descr'],
 				'budget'		=> (int)$request['budget'],
 				'location_code'		=> $request['location_code'],
-				'address'		=> $address
+				'address'		=> $address,
+				'authorities_demands' => $request['authorities_demands']
 				);
 
 			$value_set	= $this->bocommon->validate_db_update($value_set);
