@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage agreement
- 	* @version $Id: class.sos_agreement.inc.php,v 1.27 2007/01/26 14:53:47 sigurdne Exp $
+ 	* @version $Id: class.sos_agreement.inc.php,v 1.29 2007/08/12 09:30:50 sigurdne Exp $
 	*/
 
 	/**
@@ -615,7 +615,8 @@
 					'name'			=> $this->db->f('column_name'),
 					'input_text'	=> stripslashes($this->db->f('input_text')),
 					'statustext'	=> stripslashes($this->db->f('statustext')),
-					'datatype'		=> $this->db->f('datatype')
+					'datatype'		=> $this->db->f('datatype'),
+					'history'		=> $this->db->f('history')
 				);
 			}
 
@@ -747,8 +748,18 @@
 				{
 					if($entry['value'])
 					{
+						if($entry['datatype'] == 'C' || $entry['datatype'] == 'T' || $entry['datatype'] == 'V')
+						{
+							$entry['value'] = $this->db->db_addslashes($entry['value']);
+						}
+
 						$cols[]	= $entry['name'];
 						$vals[]	= $entry['value'];
+
+						if($entry['history'] == 1)
+						{
+							$history_set[$entry['attrib_id']] = $entry['value'];
+						}
 					}
 				}
 			}
@@ -798,6 +809,19 @@
 
 			$receipt['message'][] = array('msg'=>lang('s_agreement %1 has been saved',$receipt['s_agreement_id']));
 
+//---------- History
+
+			if (isset($history_set) AND is_array($history_set))
+			{
+				$historylog	= CreateObject($this->currentapp.'.historylog','s_agreement');
+				while (list($attrib_id,$new_value) = each($history_set))
+				{
+					$historylog->add('SO',$values['s_agreement_id'],$new_value,False, $attrib_id,false,$id);
+				}
+			}
+
+//----------
+
 			$this->db->transaction_commit();
 			return $receipt;
 		}
@@ -865,7 +889,26 @@
 				{
 					if($entry['datatype']!='AB' && $entry['datatype']!='VENDOR')
 					{
-						$value_set[$entry['name']]	= $entry['value'];
+						if($entry['datatype'] == 'C' || $entry['datatype'] == 'T' || $entry['datatype'] == 'V')
+						{
+							$value_set[$entry['name']] = $this->db->db_addslashes($entry['value']);
+						}
+						else
+						{
+							$value_set[$entry['name']]	= $entry['value'];
+						}
+					}
+
+					if($entry['history'] == 1)
+					{						
+						$this->db->query("SELECT " . $entry['name'] . " from $table WHERE agreement_id= " . $values['s_agreement_id'] . " AND id=" . $values['id'],__LINE__,__FILE__);
+						$this->db->next_record();
+						$old_value = $this->db->f($entry['name']);
+						if($entry['value'] != $old_value)
+						{
+							$history_set[$entry['attrib_id']] = array('value' => $entry['value'],
+												'date'  => $this->bocommon->date_to_timestamp($entry['date']));
+						}
 					}
 				}
 			}
@@ -895,9 +938,19 @@
 
 			$this->db->query("UPDATE fm_s_agreement_pricing set cost = this_index *" . $this->floatval($values['cost']) . " WHERE agreement_id=" . intval($values['s_agreement_id']) . ' AND item_id=' . intval($values['id']));
 
+			if (isset($history_set) AND is_array($history_set))
+			{
+				$historylog	= CreateObject($this->currentapp.'.historylog','s_agreement');
+				while (list($attrib_id,$history) = each($history_set))
+				{
+					$historylog->add('SO',$values['s_agreement_id'],$history['value'],False, $attrib_id,$history['date'],$values['id']);
+				}
+			}
+
 			$receipt['s_agreement_id']= $values['s_agreement_id'];
 			$receipt['id']= $values['id'];
 			$receipt['message'][] = array('msg'=>lang('s_agreement %1 has been edited',$values['s_agreement_id']));
+
 			return $receipt;
 		}
 
@@ -1096,6 +1149,7 @@
 				$attrib['lookup_form']				= $this->db->f('lookup_form');
 				$attrib['list']						= $this->db->f('list');
 				$attrib['search']					= $this->db->f('search');
+				$attrib['history']					= $this->db->f('history');
 				if($this->db->f('datatype')=='R' || $this->db->f('datatype')=='CH' || $this->db->f('datatype')=='LB')
 				{
 					$attrib['choice'] = $this->read_attrib_choice($id);
@@ -1178,6 +1232,7 @@
 				$attrib['lookup_form'],
 				$attrib['search'],
 				$attrib['list'],
+				$attrib['history'],
 				$attrib_sort,
 				$attrib['column_info']['type'],
 				$attrib['column_info']['precision'],
@@ -1190,7 +1245,7 @@
 
 			$this->db->transaction_begin();
 
-			$this->db->query("INSERT INTO $attribute_table (attrib_detail,id,column_name, input_text, statustext,lookup_form,search,list,attrib_sort,datatype,precision_,scale,default_value,nullable) "
+			$this->db->query("INSERT INTO $attribute_table (attrib_detail,id,column_name, input_text, statustext,lookup_form,search,list,history,attrib_sort,datatype,precision_,scale,default_value,nullable) "
 				. "VALUES ($values)");
 
 			$receipt['id']= $attrib['id'];
@@ -1399,6 +1454,7 @@
 				'statustext'	=> $attrib['statustext'],
 				'search'	=> $attrib['search'],
 				'list'		=> $attrib['list'],
+				'history'		=> $attrib['history'],
 				);
 
 			$value_set	= $this->bocommon->validate_db_update($value_set);
