@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage project
- 	* @version $Id: class.soworkorder.inc.php,v 1.29 2007/03/21 22:16:12 sigurdne Exp $
+ 	* @version $Id: class.soworkorder.inc.php,v 1.30 2007/08/09 11:33:27 sigurdne Exp $
 	*/
 
 	/**
@@ -207,6 +207,7 @@
 				$uicols['input_type'][]		= 'text';
 				$uicols['name'][]			= 'vendor_id';
 				$uicols['descr'][]			= lang('Vendor ID');
+				$uicols['statustext'][]		= lang('Vendor ID');
 
 				$cols .= ",fm_project.user_id as project_owner";
 
@@ -218,6 +219,21 @@
 				$uicols['input_type'][]		= 'hidden';
 				$uicols['name'][]			= 'org_name';
 				$uicols['descr'][]			= lang('Vendor name');
+				$uicols['statustext'][]		= lang('Vendor name');
+
+				$cols .= ',fm_workorder.combined_cost';
+				$cols_return[] = 'combined_cost';
+				$uicols['input_type'][]		= 'text';
+				$uicols['name'][]			= 'combined_cost';
+				$uicols['descr'][]			= lang('Cost');
+				$uicols['statustext'][]		= lang('Cost - either budget or calculation');
+
+				$cols .= ',fm_workorder.act_mtrl_cost + fm_workorder.act_vendor_cost as actual_cost';
+				$cols_return[] = 'actual_cost';
+				$uicols['input_type'][]		= 'text';
+				$uicols['name'][]			= 'actual_cost';
+				$uicols['descr'][]			= lang('Actual cost');
+				$uicols['statustext'][]		= lang('Actual cost - paid so far');
 
 				$joinmethod .= " $this->left_join  fm_vendor ON (fm_workorder.vendor_id = fm_vendor.id))";
 				$paranthesis .='(';
