@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage document
- 	* @version $Id: class.uidocument.inc.php,v 1.22 2007/05/21 07:41:42 sigurdne Exp $
+ 	* @version $Id: class.uidocument.inc.php,v 1.25 2007/08/21 12:26:04 sigurdne Exp $
 	*/
 
 	/**
@@ -208,9 +208,7 @@
 											'var'	=> 'location_code',
 											'order'	=> $this->order,
 											'extra'	=> array('menuaction'	=> $this->currentapp.'.uidocument.index',
-																	'type_id'	=> $type_id,
 																	'query'		=> $this->query,
-																	'district_id'	=> $this->district_id,
 																	'cat_id'	=> $this->cat_id,
 																	'doc_type'	=> $this->doc_type,
 																	'entity_id'	=> $this->entity_id)
@@ -225,9 +223,7 @@
 											'var'	=> 'document_id',
 											'order'	=> $this->order,
 											'extra'	=> array('menuaction'	=> $this->currentapp.'.uidocument.index',
-																	'type_id'	=> $type_id,
 																	'query'		=> $this->query,
-																	'district_id'	=> $this->district_id,
 																	'cat_id'	=> $this->cat_id,
 																	'doc_type'	=> $this->doc_type,
 																	'entity_id'	=> $this->entity_id)
@@ -242,9 +238,7 @@
 											'var'	=> 'address',
 											'order'	=> $this->order,
 											'extra'	=> array('menuaction'	=> $this->currentapp.'.uidocument.index',
-																	'type_id'	=> $type_id,
 																	'query'		=> $this->query,
-																	'district_id'	=> $this->district_id,
 																	'cat_id'	=> $this->cat_id,
 																	'doc_type'	=> $this->doc_type,
 																	'entity_id'	=> $this->entity_id)
@@ -313,10 +307,6 @@
 				'link_url'								=> $GLOBALS['phpgw']->link('/index.php',$link_data),
 				'img_path'								=> $GLOBALS['phpgw']->common->get_image_path('phpgwapi','default'),
 				'type'									=> $this->cat_id,
-//				'district_list'							=> $this->bocommon->select_district_list('filter',$this->district_id),
-//				'lang_no_district'						=> lang('no district'),
-//				'lang_district_statustext'				=> lang('Select the district the selection belongs to. To do not use a district select NO DISTRICT'),
-//				'select_district_name'					=> 'district_id',
 				'select_action'							=> $GLOBALS['phpgw']->link('/index.php',$link_data),
 
 				'lang_no_cat'							=> lang('no category'),
@@ -583,11 +573,6 @@
 				'select_name'					=> 'doc_type',
 				'cat_list'					=> $this->bocommon->select_category_list(array('format'=>'filter','selected' => $this->doc_type,'type' =>'document','order'=>'descr')),
 
-//				'district_list'					=> $this->bocommon->select_district_list('filter',$this->district_id),
-//				'lang_no_district'				=> lang('no district'),
-//				'lang_district_statustext'			=> lang('Select the district the selection belongs to. To do not use a district select NO DISTRICT'),
-//				'select_district_name'				=> 'district_id',
-
 				'select_action'					=> $GLOBALS['phpgw']->link('/index.php',$link_data),
 
 				'lang_status_statustext'			=> lang('Select the status the document belongs to. To do not use a category select NO STATUS'),
@@ -663,10 +648,14 @@
 					)
 				);
 
+				$this->bo->vfs->override_acl = 1;
+
 				$document= $this->bo->vfs->read(array(
 					'string' => $file,
 					'relatives' => Array(RELATIVE_NONE)));
 
+				$this->bo->vfs->override_acl = 0;
+
 				$browser = CreateObject('phpgwapi.browser');
 				$browser->content_header($ls_array[0]['name'],$ls_array[0]['mime_type'],$ls_array[0]['size']);
 
@@ -774,7 +763,7 @@
 
 				if(!$values['link'])
 				{
-					$values['document_name']=$_FILES['document_file']['name'];
+					$values['document_name']=str_replace (' ','_',$_FILES['document_file']['name']);
 				}
 
 				if((!$values['document_name'] && !$values['document_name_orig']) && !$values['link'])
