@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage entity
- 	* @version $Id: class.uientity.inc.php,v 1.44 2007/05/20 12:59:12 sigurdne Exp $
+ 	* @version $Id: class.uientity.inc.php,v 1.50 2007/09/21 19:28:56 sigurdne Exp $
 	*/
 
 	/**
@@ -186,7 +186,7 @@
 			
 			$values 		= get_var('values',array('POST','GET'));
 
-			if ($values['save'] && $this->cat_id)
+			if (isset($values['save']) && $values['save'] && $this->cat_id)
 			{
 				$GLOBALS['phpgw']->preferences->account_id=$this->account;
 				$GLOBALS['phpgw']->preferences->read_repository();
@@ -221,7 +221,6 @@
 				'lang_columns'		=> lang('columns'),
 				'lang_none'		=> lang('None'),
 				'lang_save'		=> lang('save'),
-				'select_name'		=> 'period'
 			);
 
 			$GLOBALS['phpgw_info']['flags']['app_header'] = $function_msg;
@@ -260,10 +259,14 @@
 					)
 				);
 
+				$this->bo->vfs->override_acl = 1;
+
 				$document= $this->bo->vfs->read(array(
 					'string' => $file,
 					'relatives' => Array(RELATIVE_NONE)));
 
+				$this->bo->vfs->override_acl = 0;
+
 				$browser = CreateObject('phpgwapi.browser');
 				$browser->content_header($ls_array[0]['name'],$ls_array[0]['mime_type'],$ls_array[0]['size']);
 
@@ -314,7 +317,7 @@
 							{
 								$content[$j]['row'][$i]['value'] 		= $entity_entry[$uicols['name'][$i]];
 								$content[$j]['row'][$i]['name'] 		= $uicols['name'][$i];
-								if($uicols['input_type'][$i]=='link')
+								if($uicols['input_type'][$i]=='link' && $entity_entry[$uicols['name'][$i]])
 								{
 									$content[$j]['row'][$i]['text']		= lang('link');
 									$content[$j]['row'][$i]['link']		= $entity_entry[$uicols['name'][$i]];
@@ -728,7 +731,7 @@
 					$values['id']=$this->bo->generate_id(array('entity_id'=>$this->entity_id,'cat_id'=>$this->cat_id));
 				}
 
-				$values['file_name']=$_FILES['file']['name'];
+				$values['file_name']=str_replace (' ','_',$_FILES['file']['name']);
 				$to_file = $this->fakebase. SEP . $this->category_name . SEP . $values['location']['loc1'] . SEP . $values['id'] . SEP . $values['file_name'];
 
 				if(!$values['document_name_orig'] && $this->bo->vfs->file_exists(array(
@@ -1360,7 +1363,7 @@
 
 		function attrib_history()
 		{
-			$GLOBALS['phpgw']->xslttpl->add_file(array('entity','nextmatchs'));
+			$GLOBALS['phpgw']->xslttpl->add_file(array('attrib_history','nextmatchs'));
 			$GLOBALS['phpgw_info']['flags']['noframework'] = True;
 
 			$id		= get_var('id',array('POST','GET'));
@@ -1427,6 +1430,16 @@
 				'lang_delete'		=> lang('delete')
 			);
 
+			$link_data = array
+			(
+				'menuaction'	=> $this->currentapp.'.uientity.attrib_history',
+				'id'			=> $id,
+				'entity_id'		=> $entity_id,
+				'cat_id'		=> $cat_id,
+				'entity_id'		=> $entity_id,
+				'edit'			=> $edit
+			);
+
 			$data = array
 			(
 				'allow_allrows'		=> false,
