@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage location
- 	* @version $Id: class.uilocation.inc.php,v 1.52 2007/03/29 08:48:58 sigurdne Exp $
+ 	* @version $Id: class.uilocation.inc.php,v 1.54 2007/09/21 19:28:56 sigurdne Exp $
 	*/
 
 	/**
@@ -53,7 +53,8 @@
 			'delete' 	=> True,
 			'update_cat'=> True,
 			'stop'		=> True,
-			'summary'	=> True
+			'summary'	=> True,
+			'columns'	=> True
 		);
 
 		function property_uilocation()
@@ -133,6 +134,51 @@
 			$this->bocommon->excel($list,$uicols['name'],$uicols['descr'],$uicols['input_type']);
 		}
 
+		function columns()
+		{
+			$GLOBALS['phpgw']->xslttpl->add_file(array('columns'));
+
+			$GLOBALS['phpgw_info']['flags']['noframework'] = True;
+			$GLOBALS['phpgw_info']['flags']['nofooter'] = True;
+			
+			$values 		= get_var('values',array('POST','GET'));
+
+			if (isset($values['save']) && $values['save'] && $this->type_id)
+			{
+				$GLOBALS['phpgw']->preferences->account_id=$this->account;
+				$GLOBALS['phpgw']->preferences->read_repository();
+				$GLOBALS['phpgw']->preferences->add($this->currentapp,"location_columns_" . $this->type_id,$values['columns'],'user');
+				$GLOBALS['phpgw']->preferences->save_repository();
+
+				$receipt['message'][] = array('msg' => lang('columns is updated'));
+			}
+
+			$function_msg	= lang('Select Column');
+
+			$link_data = array
+			(
+				'menuaction'	=> $this->currentapp.'.uilocation.columns',
+				'type_id'	=> $this->type_id
+			);
+
+
+			$msgbox_data = $this->bocommon->msgbox_data($receipt);
+
+			$data = array
+			(
+				'msgbox_data'		=> $GLOBALS['phpgw']->common->msgbox($msgbox_data),
+				'column_list'		=> $this->bo->column_list($values['columns'],$type_id=$this->type_id,$allrows=True),
+				'function_msg'		=> $function_msg,
+				'form_action'		=> $GLOBALS['phpgw']->link('/index.php',$link_data),
+				'lang_columns'		=> lang('columns'),
+				'lang_none'		=> lang('None'),
+				'lang_save'		=> lang('save'),
+			);
+
+			$GLOBALS['phpgw_info']['flags']['app_header'] = $function_msg;
+			$GLOBALS['phpgw']->xslttpl->set_var('phpgw',array('columns' => $data));
+		}
+
 
 		function index()
 		{
@@ -435,6 +481,12 @@
 				'start'			=> $this->start
 			);
 
+			$link_columns = array
+			(
+				'menuaction'	=> $this->currentapp.'.uilocation.columns',
+				'type_id'		=> $type_id
+			);
+
 			if(!$this->allrows)
 			{
 				$record_limit	= $GLOBALS['phpgw_info']['user']['preferences']['common']['maxmatchs'];
@@ -462,6 +514,10 @@
 				'link_excel'				=> $GLOBALS['phpgw']->link('/index.php',$link_excel),
 				'lang_excel_help'			=> lang('Download table to MS Excel'),
 
+				'lang_columns'				=> lang('columns'),
+				'link_columns'				=> $GLOBALS['phpgw']->link('/index.php',$link_columns),
+				'lang_columns_help'			=> lang('Choose columns'),
+
 				'exchange_values'			=> 'Exchange_values(this.form);',
 				'function_exchange_values'		=> $function_exchange_values,
 				'lang_select'				=> lang('select'),
@@ -830,12 +886,9 @@
 					}
 
 					$functions[$m]['name'] = 'lookup_'. $attributes_values[$r]['name'] .'()';
-					$functions[$m]['link'] = $GLOBALS['phpgw']->link('/index.php',array(
-												'menuaction'=>$this->currentapp.'.uilookup.addressbook',
-												'column'=> $attributes_values[$r]['name']
-												)
-											);
-					$functions[$m]['action'] = 'Window1=window.open(link,"Search","width=800,height=700,toolbar=no,scrollbars=yes,resizable=yes");';
+					$functions[$m]['link'] = "menuaction:'" . $this->currentapp.".uilookup.addressbook',"
+													. "column:'" . $attributes_values[$r]['name'] . "'";
+					$functions[$m]['action'] = 'Window1=window.open(strURL,"Search","width=800,height=700,toolbar=no,scrollbars=yes,resizable=yes");';
 					$m++;
 				}
 
@@ -855,11 +908,11 @@
 						}
 					}
 
-					$lookup_functions[$m]['name'] = 'lookup_'. $attributes_values[$r]['name'] .'()';
-					$lookup_functions[$m]['link'] = "menuaction:'" . $this->currentapp.".uilookup.vendor',"
-													. "column':" . $attributes_values[$r]['name'] . "'";
-													
-					$lookup_functions[$m]['action'] = 'Window1=window.open(strURL,"Search","width=800,height=700,toolbar=no,scrollbars=yes,resizable=yes");';
+					$functions[$m]['name'] = 'lookup_'. $attributes_values[$r]['name'] .'()';
+					$functions[$m]['link'] = "menuaction:'" . $this->currentapp.".uilookup.vendor',"
+													. "column:'" . $attributes_values[$r]['name'] . "'";												
+
+					$functions[$m]['action'] = 'Window1=window.open(strURL,"Search","width=800,height=700,toolbar=no,scrollbars=yes,resizable=yes");';
 					$m++;
 				}
 
