@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage agreement
- 	* @version $Id: class.uir_agreement.inc.php,v 1.28 2007/05/21 07:41:42 sigurdne Exp $
+ 	* @version $Id: class.uir_agreement.inc.php,v 1.30 2007/08/14 10:45:09 sigurdne Exp $
 	*/
 
 	/**
@@ -192,10 +192,14 @@
 					)
 				);
 
+				$this->bo->vfs->override_acl = 1;
+
 				$document= $this->bo->vfs->read(array(
 					'string' => $file,
 					'relatives' => Array(RELATIVE_NONE)));
 
+				$this->bo->vfs->override_acl = 0;
+
 				$browser = CreateObject('phpgwapi.browser');
 				$browser->content_header($ls_array[0]['name'],$ls_array[0]['mime_type'],$ls_array[0]['size']);
 
@@ -594,7 +598,7 @@
 						$values['r_agreement_id']=$this->bo->request_next_id();
 					}
 
-					$values['file_name']=$_FILES['file']['name'];
+					$values['file_name']=str_replace (' ','_',$_FILES['file']['name']);
 					$to_file = $this->fakebase. SEP . 'rental_agreement' . SEP . $values['r_agreement_id'] . SEP . $values['file_name'];
 
 					if(!$values['document_name_orig'] && $this->bo->vfs->file_exists(array(
