@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage agreement
- 	* @version $Id: class.uis_agreement.inc.php,v 1.40 2007/05/21 07:41:42 sigurdne Exp $
+ 	* @version $Id: class.uis_agreement.inc.php,v 1.47 2007/08/14 10:45:09 sigurdne Exp $
 	*/
 
 	/**
@@ -54,7 +54,8 @@
 			'edit_item'		=> True,
 			'view_item'		=> True,
 			'view_file'		=> True,
-			'excel'			=> True
+			'excel'			=> True,
+			'attrib_history'=> True,			
 		);
 
 		function property_uis_agreement()
@@ -188,10 +189,14 @@
 					)
 				);
 
+				$this->bo->vfs->override_acl = 1;
+
 				$document= $this->bo->vfs->read(array(
 					'string' => $file,
 					'relatives' => Array(RELATIVE_NONE)));
 
+				$this->bo->vfs->override_acl = 0;
+
 				$browser = CreateObject('phpgwapi.browser');
 				$browser->content_header($ls_array[0]['name'],$ls_array[0]['mime_type'],$ls_array[0]['size']);
 
@@ -429,11 +434,11 @@
 						}
 					}
 
-					if($this->acl_read && !$edit_item && !$view_only)
+					if($this->acl_read)
 					{
 						$content[$j]['row'][$i]['statustext']			= lang('view the entity');
 						$content[$j]['row'][$i]['text']					= lang('view');
-						$content[$j]['row'][$i++]['link']				= $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.uis_agreement.view_item', 's_agreement_id'=> $entry['agreement_id'], 'id'=> $entry['id']));
+						$content[$j]['row'][$i++]['link']				= $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.uis_agreement.view_item', 's_agreement_id'=> $entry['agreement_id'], 'id'=> $entry['id'], 'from'=> $view_only?'view':'edit'));
 					}
 					if($this->acl_edit && !$edit_item && !$view_only)
 					{
@@ -463,7 +468,7 @@
 				}
 			}
 
-			if($this->acl_read && !$edit_item && !$view_only)
+			if($this->acl_read)
 			{
 				$table_header[$i]['width'] 			= '5%';
 				$table_header[$i]['align'] 			= 'center';
@@ -564,7 +569,7 @@
 						$values['s_agreement_id']=$this->bo->request_next_id();
 					}
 
-					$values['file_name']=$_FILES['file']['name'];
+					$values['file_name'] = str_replace (' ','_',$_FILES['file']['name']);
 					$to_file = $this->fakebase. SEP . 'service_agreement' . SEP . $values['s_agreement_id'] . SEP . $values['file_name'];
 
 					if(!$values['document_name_orig'] && $this->bo->vfs->file_exists(array(
@@ -1021,7 +1026,6 @@
 			$s_agreement = $this->bo->read_single(array('s_agreement_id'=>$s_agreement_id));
 			$values = $this->bo->read_single_item(array('s_agreement_id'=>$s_agreement_id,'id'=>$id));
 
-
 			$link_data = array
 			(
 				'menuaction'		=> $this->currentapp.'.uis_agreement.edit_item',
@@ -1115,6 +1119,25 @@
 						'entity_data'	=> $values['p']
 						));
 
+			for ($i=0;$i<count($values['attributes']);$i++)
+			{
+				if($values['attributes'][$i]['history']==1)
+				{
+					$link_history_data = array
+					(
+						'menuaction'	=> $this->currentapp.'.uis_agreement.attrib_history',
+						's_agreement_id'	=> $s_agreement_id,
+						'attrib_id'	=> $values['attributes'][$i]['attrib_id'],
+						'item_id'	=> $id,
+						'edit'		=> True,
+						'role'		=>'detail'
+					);
+
+					$values['attributes'][$i]['link_history']=$GLOBALS['phpgw']->link('/index.php',$link_history_data);
+				}
+			}
+
+			$GLOBALS['phpgw']->js->validate_file('overlib','overlib',$this->currentapp);
 			$GLOBALS['phpgw']->js->validate_file('core','check',$this->currentapp);
 			$GLOBALS['phpgw']->js->validate_file('dateformat','dateformat',$this->currentapp);
 
@@ -1167,6 +1190,10 @@
 				'lang_delete_last_statustext'			=> lang('delete the last index'),
 				'delete_action'					=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.uis_agreement.edit_item', 'delete_last'=>1, 's_agreement_id'=> $s_agreement_id, 'id'=> $id)),
 
+				'lang_history'					=> lang('history'),
+				'lang_history_help'				=> lang('history of this attribute'),
+				'lang_history_date_statustext'	=> lang('Enter the date for this reading'),
+
 			);
 
 			$GLOBALS['phpgw_info']['flags']['app_header'] = lang('service agreement') . ': ' . ($values['id']?lang('edit item') . ' ' . $s_agreement['name']:lang('add item') . ' ' . $s_agreement['name']);
@@ -1177,6 +1204,8 @@
 
 		function view_item()
 		{
+			$from = get_var('from',array('POST','GET'));
+			$from = $from == 'edit'?'edit':'view';
 			$s_agreement_id	= get_var('s_agreement_id',array('POST','GET'));
 			$id	= get_var('id',array('POST','GET'));
 
@@ -1189,7 +1218,7 @@
 
 			$link_data = array
 			(
-				'menuaction'	=> $this->currentapp.'.uis_agreement.edit',
+				'menuaction'	=> $this->currentapp.'.uis_agreement.' . $from,
 				'id'		=> $s_agreement_id
 			);
 
@@ -1224,6 +1253,26 @@
 						'entity_data'	=> $values['p']
 						));
 
+
+			for ($i=0;$i<count($values['attributes']);$i++)
+			{
+				if($values['attributes'][$i]['history']==1)
+				{
+					$link_history_data = array
+					(
+						'menuaction'	=> $this->currentapp.'.uis_agreement.attrib_history',
+						's_agreement_id'	=> $s_agreement_id,
+						'attrib_id'	=> $values['attributes'][$i]['attrib_id'],
+						'item_id'	=> $id,
+						'edit'		=> False,
+						'role'		=>'detail'
+					);
+
+					$values['attributes'][$i]['link_history']=$GLOBALS['phpgw']->link('/index.php',$link_history_data);
+				}
+			}
+
+			$GLOBALS['phpgw']->js->validate_file('overlib','overlib',$this->currentapp);
 			$GLOBALS['phpgw']->js->validate_file('core','check',$this->currentapp);
 
 			$data = array
@@ -1251,6 +1300,9 @@
 				'lang_cost_statustext'				=> lang('cost'),
 				'value_cost'					=> $values['cost'],
 				'set_column'					=> $set_column,
+
+				'lang_history'					=> lang('history'),
+				'lang_history_help'				=> lang('history of this attribute'),
 			);
 
 			$GLOBALS['phpgw_info']['flags']['app_header'] = lang('service agreement') . ': ' . lang('view item') . ' ' . $s_agreement['name'];
@@ -1758,6 +1810,10 @@
 				'value_search'				=> $values['search'],
 				'lang_include_search'			=> lang('Include in search'),
 				'lang_include_search_statustext'	=> lang('check to show this attribute in location list'),
+
+				'value_history'						=> $values['history'],
+				'lang_history'						=> lang('history'),
+				'lang_history_statustext'			=> lang('Enable history for this attribute'),
 			);
 	//html_print_r($data);
 
@@ -1767,5 +1823,104 @@
 			$GLOBALS['phpgw']->xslttpl->set_var('phpgw',array('edit_attrib' => $data));
 		//	$GLOBALS['phpgw']->xslttpl->pp();
 		}
+
+		function attrib_history()
+		{
+			$GLOBALS['phpgw']->xslttpl->add_file(array('attrib_history','nextmatchs'));
+			$GLOBALS['phpgw_info']['flags']['noframework'] = True;
+
+			$s_agreement_id		= get_var('s_agreement_id',array('POST','GET'));
+			$item_id	= get_var('item_id',array('POST','GET'));
+			$attrib_id 	= get_var('attrib_id',array('POST','GET'));
+
+			$data_lookup= array(
+				'id'		=> $s_agreement_id,
+				'item_id'	=> $item_id,
+				'attrib_id' 	=> $attrib_id
+				);
+
+			$delete = get_var('delete',array('POST','GET'));
+			$edit = get_var('edit',array('POST','GET'));
+
+			if ($delete)
+			{
+				$data_lookup['history_id'] = get_var('history_id',array('POST','GET'));
+				$this->bo->delete_history_item($data_lookup);
+			}
+
+			$values = $this->bo->read_attrib_history($data_lookup);
+			$dateformat = $GLOBALS['phpgw_info']['user']['preferences']['common']['dateformat'];
+
+			while (is_array($values) && list(,$entry) = each($values))
+			{
+				$link_delete_history_data = array
+					(
+						'menuaction'	=> $this->currentapp.'.uis_agreement.attrib_history',
+						's_agreement_id'	=> $s_agreement_id,
+						'item_id'		=> $item_id,
+						'attrib_id'	=> $attrib_id,
+						'history_id'	=> $entry['id'],
+						'delete'	=> true,
+						'edit'		=> true,
+						'role'		=> $this->bo->role
+					);
+				if($edit)
+				{
+					$text_delete	= lang('delete');
+					$link_delete	= $GLOBALS['phpgw']->link('/index.php',$link_delete_history_data);
+				}
+
+				$content[] = array
+				(
+					'id'				=> $entry['id'],
+					'value'				=> $entry['new_value'],
+					'user'				=> $entry['owner'],
+					'time_created'			=> $GLOBALS['phpgw']->common->show_date($entry['datetime'],$dateformat),
+					'link_delete'			=> $link_delete,
+					'lang_delete_statustext'	=> lang('delete the item'),
+					'text_delete'			=> $text_delete,
+				);
+			}
+
+
+			$table_header = array
+			(
+				'lang_value'		=> lang('value'),
+				'lang_user'		=> lang('user'),
+				'lang_time_created'	=> lang('time created'),
+				'lang_delete'		=> lang('delete')
+			);
+
+			$link_data = array
+			(
+				'menuaction'	=> $this->currentapp.'.uis_agreement.attrib_history',
+				's_agreement_id'=> $s_agreement_id,
+				'item_id'		=> $item_id,
+				'attrib_id'	=> $attrib_id,
+				'edit'			=> $edit
+			);
+
+			$data = array
+			(
+				'allow_allrows'		=> false,
+				'start_record'		=> $this->start,
+				'record_limit'		=> $GLOBALS['phpgw_info']['user']['preferences']['common']['maxmatchs'],
+				'num_records'		=> count($values),
+				'all_records'		=> $this->bo->total_records,
+				'link_url'		=> $GLOBALS['phpgw']->link('/index.php',$link_data),
+				'img_path'		=> $GLOBALS['phpgw']->common->get_image_path('phpgwapi','default'),
+				'values' 		=> $content,
+				'table_header'		=> $table_header,
+			);
+//_debug_array($data);
+			$this->bo->role='detail';
+			$attrib_data 	= $this->bo->read_single_attrib($attrib_id);
+			$appname	= $attrib_data['input_text'];
+			$function_msg	= lang('history');
+
+			$GLOBALS['phpgw_info']['flags']['app_header'] = lang($this->currentapp) . ' - ' . $appname . ': ' . $function_msg;	
+
+			$GLOBALS['phpgw']->xslttpl->set_var('phpgw',array('attrib_history' => $data));
+		}
 	}
 ?>
