@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage helpdesk
- 	* @version $Id: class.uitts.inc.php,v 1.58 2007/05/20 12:59:12 sigurdne Exp $
+ 	* @version $Id: class.uitts.inc.php,v 1.63 2007/08/24 13:59:13 sigurdne Exp $
 	*/
 
 	/**
@@ -249,16 +249,16 @@
 				$this->filter	= $default_status;
 			}
 
-			$bgcolor['1']	= '#dadada';
-			$bgcolor['2']	= '#dad0d0';
-			$bgcolor['3']	= '#dacaca';
-			$bgcolor['4']	= '#dac0c0';
-			$bgcolor['5']	= '#dababa';
-			$bgcolor['6']	= '#dab0b0';
-			$bgcolor['7']	= '#daaaaa';
-			$bgcolor['8']	= '#da9090';
-			$bgcolor['9']	= '#da8a8a';
-			$bgcolor['10']	= '#da7a7a';
+			$bgcolor_array[1]	= '#dadada';
+			$bgcolor_array[2]	= '#dad0d0';
+			$bgcolor_array[3]	= '#dacaca';
+			$bgcolor_array[4]	= '#dac0c0';
+			$bgcolor_array[5]	= '#dababa';
+			$bgcolor_array[6]	= '#dab0b0';
+			$bgcolor_array[7]	= '#daaaaa';
+			$bgcolor_array[8]	= '#da9090';
+			$bgcolor_array[9]	= '#da8a8a';
+			$bgcolor_array[10]	= '#da7a7a';
 
 
 			$links = $this->menu->links();
@@ -280,60 +280,67 @@
 					$first= $ticket['category'];
 				}
 
-				if ($ticket['status']=='O')
+				switch ($ticket['status'])
 				{
-					$status = lang('Open');
-					$text_edit_status = lang('Close');
-					$new_status = 'X';
-				}
-				else
-				{
-					$status = lang('Closed');
-					$text_edit_status = lang('Open');
-					$new_status = 'O';
-				}
-
+					case 'X': 
+						$bgcolor = '#5EFB6E'; 
+						$status = lang('Closed');
+						$text_edit_status = lang('Open');
+						$new_status = 'O';
+					break;
+					case 'I': 
+						$bgcolor = '#FF9933'; 
+						$status = lang('In progress');
+						$text_edit_status = lang('Close');
+						$new_status = 'X';
+					break;
+					default :
+						$bgcolor = $bgcolor_array[$ticket['priority']];
+						$status = lang('Open');
+						$text_edit_status = lang('Close');
+						$new_status = 'X';
+					break;
+				}			
 
 				$link_status_data = array
 				(
-					'menuaction'	=> $this->currentapp.'.uitts.index',
-							'id'		=> $ticket['id'],
+					'menuaction'			=> $this->currentapp.'.uitts.index',
+							'id'			=> $ticket['id'],
 							'edit_status'	=> true,
 							'new_status'	=> $new_status,
 							'second_display'=> true,
-							'sort'		=>$this->sort,
-							'order'		=>$this->order,
-							'cat_id'	=>$this->cat_id,
-							'filter'	=>$this->filter,
-							'user_filter'	=>$this->user_filter,
-							'query'		=>$this->query,
+							'sort'			=> $this->sort,
+							'order'			=> $this->order,
+							'cat_id'		=> $this->cat_id,
+							'filter'		=> $this->filter,
+							'user_filter'	=> $this->user_filter,
+							'query'			=> $this->query,
 							'district_id'	=> $this->district_id,
-							'allrows'	=>$this->allrows
+							'allrows'		=> $this->allrows
 				);
-
-
+				
 				$content[] = array
 				(
 					'id'					=> $ticket['id'],
-					'bgcolor'				=> $bgcolor[$ticket['priority']],
-					'new_ticket'				=> (isset($ticket['new_ticket'])?$ticket['new_ticket']:''),
+					'bgcolor'				=> $bgcolor,
+					'new_ticket'			=> (isset($ticket['new_ticket'])?$ticket['new_ticket']:''),
 					'priostr'				=> $ticket['priority'],
 					'first'					=> $first,
-					'location_code'				=> $ticket['location_code'],
+					'location_code'			=> $ticket['location_code'],
 					'address'				=> $ticket['address'],
 					'date'					=> $ticket['timestampopened'],
-					'finnish_date'				=> $ticket['finnish_date'],
+					'finnish_date'			=> $ticket['finnish_date'],
 					'delay'					=> (isset($ticket['delay'])?$ticket['delay']:''),
 					'user'					=> $ticket['user'],
-					'assignedto'				=> $ticket['assignedto'],
-					'child_date'				=> $ticket['child_date'],
+					'assignedto'			=> $ticket['assignedto'],
+					'child_date'			=> $ticket['child_date'],
 					'link_view'				=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.uitts.view', 'id'=> $ticket['id'])),
-					'lang_view_statustext'			=> lang('view the ticket'),
+					'lang_view_statustext'	=> lang('view the ticket'),
 					'text_view'				=> lang('view'),
 					'status'				=> $status,
-					'link_edit_status'			=> $GLOBALS['phpgw']->link('/index.php',$link_status_data),
-					'lang_edit_status'			=> lang('Edit status'),
-					'text_edit_status'			=> $text_edit_status
+					'link_edit_status'		=> $GLOBALS['phpgw']->link('/index.php',$link_status_data),
+					'lang_edit_status'		=> lang('Edit status'),
+					'text_edit_status'		=> $text_edit_status,
 				);
 			}
 
@@ -550,56 +557,57 @@
 
 			$data = array
 			(
-				'group_filters'				=> $pref_group_filters,
-				'lang_excel'				=> 'excel',
-				'link_excel'				=> $GLOBALS['phpgw']->link('/index.php',$link_excel),
-				'lang_excel_help'			=> lang('Download table to MS Excel'),
+				'group_filters'					=> $pref_group_filters,
+				'lang_excel'					=> 'excel',
+				'link_excel'					=> $GLOBALS['phpgw']->link('/index.php',$link_excel),
+				'lang_excel_help'				=> lang('Download table to MS Excel'),
 
-				'start_date'				=> $start_date,
-				'end_date'				=> $end_date,
-				'lang_none'				=> lang('None'),
-				'lang_date_search'			=> lang('Date search'),
+				'start_date'					=> $start_date,
+				'end_date'						=> $end_date,
+				'lang_none'						=> lang('None'),
+				'lang_date_search'				=> lang('Date search'),
 				'lang_date_search_help'			=> lang('Narrow the search by dates'),
-				'link_date_search'			=> $link_date_search,
+				'link_date_search'				=> $link_date_search,
 
-				'msgbox_data'				=> $GLOBALS['phpgw']->common->msgbox($msgbox_data),
-				'autorefresh'				=> $autorefresh,
-				'links'					=> $links,
-				'allow_allrows'				=> True,
-				'allrows'				=> $this->allrows,
-				'start_record'				=> $this->start,
-				'record_limit'				=> $record_limit,
-				'num_records'				=> count($ticket_list),
-				'all_records'				=> $this->bo->total_records,
-				'link_url'				=> $GLOBALS['phpgw']->link('/index.php',$link_data),
-				'img_path'				=> $GLOBALS['phpgw']->common->get_image_path('phpgwapi','default'),
-				'lang_no_cat'				=> lang('no category'),
+				'msgbox_data'					=> $GLOBALS['phpgw']->common->msgbox($msgbox_data),
+				'autorefresh'					=> $autorefresh,
+				'links'							=> $links,
+				'allow_allrows'					=> True,
+				'allrows'						=> $this->allrows,
+				'start_record'					=> $this->start,
+				'record_limit'					=> $record_limit,
+				'num_records'					=> count($ticket_list),
+				'all_records'					=> $this->bo->total_records,
+				'link_url'						=> $GLOBALS['phpgw']->link('/index.php',$link_data),
+				'img_path'						=> $GLOBALS['phpgw']->common->get_image_path('phpgwapi','default'),
+				'lang_no_cat'					=> lang('no category'),
 				'lang_cat_statustext'			=> lang('Select the category the ticket belongs to. To do not use a category select NO CATEGORY'),
-				'select_name'				=> 'cat_id',
-				'cat_list'				=> $this->bocommon->select_category_list(array('format'=>$group_filters,'selected' => $this->cat_id,'type' =>'ticket','order'=>'descr')),
+				'select_name'					=> 'cat_id',
+				'cat_list'						=> $this->bocommon->select_category_list(array('format'=>$group_filters,'selected' => $this->cat_id,'type' =>'ticket','order'=>'descr')),
 
-				'select_action'				=> $GLOBALS['phpgw']->link('/index.php',$link_data),
-				'filter_name'				=> 'filter',
-				'filter_list'				=> $this->bo->filter(array('format' => $group_filters, 'filter'=> $this->filter,'default' => 'open')),
-				'lang_show_all'				=> lang('Open'),
+				'select_action'					=> $GLOBALS['phpgw']->link('/index.php',$link_data),
+				'filter_name'					=> 'filter',
+				'filter_list'					=> $this->bo->filter(array('format' => $group_filters, 'filter'=> $this->filter,'default' => 'open')),
+				'lang_show_all'					=> lang('Open'),
 				'lang_filter_statustext'		=> lang('Select the filter. To show all entries select SHOW ALL'),
-				'lang_searchfield_statustext'		=> lang('Enter the search string. To show all entries, empty this field and press the SUBMIT button again'),
-				'lang_searchbutton_statustext'		=> lang('Submit the search string'),
-				'query'					=> $this->query,
-				'lang_search'				=> lang('search'),
-				'table_header'				=> $table_header,
-				'values'				=> (isset($content)?$content:''),
-				'table_add'				=> $table_add,
+				'lang_searchfield_statustext'	=> lang('Enter the search string. To show all entries, empty this field and press the SUBMIT button again'),
+				'lang_searchbutton_statustext'	=> lang('Submit the search string'),
+				'query'							=> $this->query,
+				'lang_search'					=> lang('search'),
+				'table_header'					=> $table_header,
+				'values'						=> (isset($content)?$content:''),
+				'table_add'						=> $table_add,
 
-				'district_list'				=> $this->bocommon->select_district_list($group_filters,$this->district_id),
-				'lang_no_district'			=> lang('no district'),
+				'district_list'					=> $this->bocommon->select_district_list($group_filters,$this->district_id),
+				'lang_no_district'				=> lang('no district'),
 				'lang_district_statustext'		=> lang('Select the district the selection belongs to. To do not use a district select NO DISTRICT'),
 				'select_district_name'			=> 'district_id',
 
 				'lang_user_statustext'			=> lang('Assigned to'),
-				'select_user_name'			=> 'user_filter',
-				'lang_no_user'				=> lang('No user'),
-				'user_list'				=> $this->bocommon->get_user_list_right2($group_filters,4,$this->user_filter,$this->acl_location,'',$default='')
+				'select_user_name'				=> 'user_filter',
+				'lang_no_user'					=> lang('No user'),
+				'user_list'						=> $this->bocommon->get_user_list_right2($group_filters,4,$this->user_filter,$this->acl_location,'',$default=''),
+				'allow_edit_status'				=> isset($GLOBALS['phpgw_info']['user']['preferences'][$this->currentapp]['tts_status_link']) && $GLOBALS['phpgw_info']['user']['preferences'][$this->currentapp]['tts_status_link'] ? $GLOBALS['phpgw_info']['user']['preferences'][$this->currentapp]['tts_status_link']:''
 			);
 
 			$appname					= lang('helpdesk');
@@ -1026,8 +1034,6 @@
 
 				if(!isset($receipt['error']))
 				{
-					$receipt	= $this->bo->create_home_dir($receipt);
-
 					$receipt = $this->bo->add($values);
 
 					$values['file_name']=str_replace(' ','_',$_FILES['file']['name']);
@@ -2069,10 +2075,14 @@
 					)
 				);
 
+				$this->bo->vfs->override_acl = 1;
+
 				$document= $this->bo->vfs->read(array(
 					'string' => $file,
 					'relatives' => Array(RELATIVE_NONE)));
 
+				$this->bo->vfs->override_acl = 0;
+
 				$browser = CreateObject('phpgwapi.browser');
 				$browser->content_header($ls_array[0]['name'],$ls_array[0]['mime_type'],$ls_array[0]['size']);
 
