@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage project
- 	* @version $Id: class.uiworkorder.inc.php,v 1.40 2007/01/26 14:53:47 sigurdne Exp $
+ 	* @version $Id: class.uiworkorder.inc.php,v 1.43 2007/03/23 16:02:48 sigurdne Exp $
 	*/
 
 	/**
@@ -466,7 +466,7 @@
 				'lang_user_statustext'			=> lang('Select the user the workorder belongs to. To do not use a category select NO USER'),
 				'select_user_name'				=> 'filter',
 				'lang_no_user'					=> lang('No user'),
-				'user_list'						=> $this->bocommon->get_user_list_right2($group_filters,4,$this->filter,$this->acl_location),
+				'user_list'						=> $this->bocommon->get_user_list_right2($group_filters,2,$this->filter,$this->acl_location),
 
 				'lang_searchvendor_statustext'	=> lang('Enter the vendor name to search for'),
 				'lang_searchfield_statustext'	=> lang('Enter the search string. To show all entries, empty this field and press the SUBMIT button again'),
@@ -823,8 +823,22 @@
 				$msgbox_data = '';
 			}
 
+			$GLOBALS['phpgw']->js->validate_file('tabs', 'tabs');
+
+			if(!is_object($GLOBALS['phpgw']->css))
+			{
+				$GLOBALS['phpgw']->css = createObject('phpgwapi.css');
+			}
+			$GLOBALS['phpgw']->css->validate_file('tabs','phpgwapi');
+
 			$data = array
 			(
+				'lang_project_info'				=> lang('Project info'),
+				'lang_general' 					=> lang('general'),
+				'lang_coordination' 			=> lang('coordination'),
+				'lang_time_and_budget' 			=> lang('time and budget'),
+				'lang_extra' 					=> lang('extra'),
+
 				'msgbox_data'				=> $GLOBALS['phpgw']->common->msgbox($msgbox_data),
 				'calculate_action'			=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.uiwo_hour.index')),
 				'lang_calculate'			=> lang('Calculate Workorder'),
