@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage custom
- 	* @version $Id: synkroniser_med_boei.php,v 1.5 2007/03/23 12:05:41 sigurdne Exp $
+ 	* @version $Id: synkroniser_med_boei.php,v 1.7 2007/09/24 11:20:27 sigurdne Exp $
 	*/
 
 	/**
@@ -268,7 +268,7 @@
 				$sql2_latin = "INSERT INTO fm_owner (id,org_name,remark,category,entry_date,owner_id)"
 					. "VALUES (" . $this->bocommon->validate_db_insert($owner_latin[$i]) . ")";
 
-				$this->db->query($sql2_utf,__LINE__,__FILE__);
+				$this->db->query($sql2_latin,__LINE__,__FILE__);
 				$this->db_boei->query($sql2_latin,__LINE__,__FILE__);
 
 				$owner_msg[]=$owner_utf[$i]['org_name'];
@@ -279,7 +279,8 @@
 
 			$msg = count($owner) . ' eier er lagt til: ' . @implode(",", $owner_msg);
 			$this->receipt['message'][]=array('msg'=> $msg);
-			unset ($owner);
+			unset ($owner_utf);
+			unset ($owner_latin);
 			unset ($owner_msg);
 			return $msg;
 
@@ -317,7 +318,7 @@
 
 				$this->db->query($sql,__LINE__,__FILE__);
 				$this->db_boei->query($sql,__LINE__,__FILE__);
-				$this->db->query($sql2_utf,__LINE__,__FILE__);
+				$this->db->query($sql2_latin,__LINE__,__FILE__);
 				$this->db_boei->query($sql2_latin,__LINE__,__FILE__);
 				$gate_msg[]=$this->bocommon->ascii2utf($gate[$i]['descr']);
 			}
@@ -365,7 +366,7 @@
 	//		$this->db->transaction_begin();
 	//		$this->db_boei->transaction_begin();
 
-			for ($i=0; $i<count($objekt); $i++)
+			for ($i=0; $i<count($objekt_latin); $i++)
 			{
 
 				$sql2_utf = "INSERT INTO fm_location1 (location_code, loc1, loc1_name, part_of_town_id, owner_id, kostra_id) "
@@ -373,7 +374,7 @@
 				$sql2_latin = "INSERT INTO fm_location1 (location_code, loc1, loc1_name, part_of_town_id, owner_id, kostra_id) "
 					. "VALUES (" . $this->bocommon->validate_db_insert($objekt_latin[$i]) . ")";
 
-				$this->db->query($sql2_utf,__LINE__,__FILE__);
+				$this->db->query($sql2_latin,__LINE__,__FILE__);
 				$this->db_boei->query($sql2_latin,__LINE__,__FILE__);
 
 				$obj_msg[]=$objekt_utf[$i]['loc1'];
@@ -382,9 +383,10 @@
 	//		$this->db->transaction_commit();
 	//		$this->db_boei->transaction_commit();
 
-			$msg = count($objekt) . ' Objekt er lagt til: ' . @implode(",", $obj_msg);
+			$msg = count($objekt_latin) . ' Objekt er lagt til: ' . @implode(",", $obj_msg);
 			$this->receipt['message'][]=array('msg'=> $msg);
-			unset ($objekt);
+			unset ($objekt_utf);
+			unset ($objekt_latin);
 			unset ($obj_msg);
 			return $msg;
 		}
@@ -417,7 +419,7 @@
 		//	$this->db->transaction_begin();
 		//	$this->db_boei->transaction_begin();
 
-			for ($i=0; $i<count($bygg); $i++)
+			for ($i=0; $i<count($bygg_latin); $i++)
 			{
 
 				$sql2_utf = "INSERT INTO fm_location2 (location_code, loc1, loc2, loc2_name) "
@@ -425,7 +427,7 @@
 				$sql2_latin = "INSERT INTO fm_location2 (location_code, loc1, loc2, loc2_name) "
 					. "VALUES (" . $this->bocommon->validate_db_insert($bygg_latin[$i]) . ")";
 
-				$this->db->query($sql2_utf,__LINE__,__FILE__);
+				$this->db->query($sql2_latin,__LINE__,__FILE__);
 				$this->db_boei->query($sql2_latin,__LINE__,__FILE__);
 
 				$bygg_msg[]=$bygg_utf[$i]['location_code'];
@@ -434,9 +436,10 @@
 		//	$this->db->transaction_commit();
 		//	$this->db_boei->transaction_commit();
 
-			$msg = count($bygg) . ' Bygg er lagt til: ' . @implode(",", $bygg_msg);
+			$msg = count($bygg_latin) . ' Bygg er lagt til: ' . @implode(",", $bygg_msg);
 			$this->receipt['message'][]=array('msg'=> $msg);
-			unset ($bygg);
+			unset ($bygg_utf);
+			unset ($bygg_latin);
 			unset ($bygg_msg);
 			return $msg;
 
@@ -477,7 +480,7 @@
 		//	$this->db->transaction_begin();
 		//	$this->db_boei->transaction_begin();
 
-			for ($i=0; $i<count($seksjon); $i++)
+			for ($i=0; $i<count($seksjon_latin); $i++)
 			{
 
 				$sql2_utf = "INSERT INTO fm_location3 (location_code, loc1, loc2, loc3, loc3_name, fellesareal) "
@@ -485,7 +488,7 @@
 				$sql2_latin = "INSERT INTO fm_location3 (location_code, loc1, loc2, loc3, loc3_name, fellesareal) "
 					. "VALUES (" . $this->bocommon->validate_db_insert($seksjon_latin[$i]) . ")";
 
-				$this->db->query($sql2_utf,__LINE__,__FILE__);
+				$this->db->query($sql2_latin,__LINE__,__FILE__);
 				$this->db_boei->query($sql2_latin,__LINE__,__FILE__);
 
 				$seksjon_msg[]=$seksjon_utf[$i]['location_code'];
@@ -494,9 +497,10 @@
 		//	$this->db->transaction_commit();
 		//	$this->db_boei->transaction_commit();
 
-			$msg = count($seksjon) . ' Seksjon er lagt til: ' . @implode(",", $seksjon_msg);
+			$msg = count($seksjon_latin) . ' Seksjon er lagt til: ' . @implode(",", $seksjon_msg);
 			$this->receipt['message'][]=array('msg'=> $msg);
-			unset ($seksjon);
+			unset ($seksjon_utf);
+			unset ($seksjon_latin);
 			unset ($seksjon_msg);
 			return $msg;
 		}
@@ -508,7 +512,7 @@
                   . " v_Leieobjekt.objekt_id, v_Leieobjekt.leie_id, v_Leieobjekt.leieobjekttype_id, v_Leieobjekt.bygg_id, v_Leieobjekt.seksjons_id,"
                   . " v_Leieobjekt.formaal_id, v_Leieobjekt.gateadresse_id, v_Leieobjekt.gatenr, v_Leieobjekt.etasje, v_Leieobjekt.antallrom,"
                   . " v_Leieobjekt.boareal, v_Leieobjekt.livslopsstd, v_Leieobjekt.heis, v_Leieobjekt.driftsstatus_id, v_Leieobjekt.leietaker_id,"
-                  . " v_Leieobjekt.beregnet_boa"
+                  . " v_Leieobjekt.beregnet_boa, v_Leieobjekt.flyttenr"
                   . " FROM v_Leieobjekt LEFT OUTER JOIN"
                   . " fm_location4 ON v_Leieobjekt.objekt_id = fm_location4.loc1 AND v_Leieobjekt.leie_id = fm_location4.loc4"
                   . " WHERE fm_location4.loc1 IS NULL";
@@ -535,7 +539,8 @@
 				 'heis' 			=> $this->db_boei->f('heis'),
 				 'driftsstatus_id' 	=> $this->db_boei->f('driftsstatus_id'),
 				 'tenant_id'	 	=> $this->db_boei->f('leietaker_id'),
-				 'beregnet_boa' 	=> $this->db_boei->f('beregnet_boa')
+				 'beregnet_boa' 	=> $this->db_boei->f('beregnet_boa'),
+				 'flyttenr' 		=> $this->db_boei->f('flyttenr')
 				 );
 				$leieobjekt_latin[]= array (
 				 'location_code' 	=> $this->db_boei->f('location_code'),
@@ -554,7 +559,8 @@
 				 'heis' 			=> $this->db_boei->f('heis'),
 				 'driftsstatus_id' 	=> $this->db_boei->f('driftsstatus_id'),
 				 'tenant_id'	 	=> $this->db_boei->f('leietaker_id'),
-				 'beregnet_boa' 	=> $this->db_boei->f('beregnet_boa')
+				 'beregnet_boa' 	=> $this->db_boei->f('beregnet_boa'),
+				 'flyttenr' 		=> $this->db_boei->f('flyttenr')
 				 );
 
 			}
@@ -562,17 +568,17 @@
 		//	$this->db->transaction_begin();
 		//	$this->db_boei->transaction_begin();
 
-			for ($i=0; $i<count($leieobjekt); $i++)
+			for ($i=0; $i<count($leieobjekt_latin); $i++)
 			{
 
 				$sql2_utf = "INSERT INTO fm_location4 (location_code, loc1, loc4, leieobjekttype_id, loc2, loc3, category, street_id, street_number, etasje, antallrom, boareal, livslopsstd, heis, driftsstatus_id,
-                      tenant_id, beregnet_boa)"
+                      tenant_id, beregnet_boa, flyttenr)"
 					. "VALUES (" . $this->bocommon->validate_db_insert($leieobjekt_utf[$i]) . ")";
 				$sql2_latin = "INSERT INTO fm_location4 (location_code, loc1, loc4, leieobjekttype_id, loc2, loc3, category, street_id, street_number, etasje, antallrom, boareal, livslopsstd, heis, driftsstatus_id,
-                      tenant_id, beregnet_boa)"
+                      tenant_id, beregnet_boa, flyttenr)"
 					. "VALUES (" . $this->bocommon->validate_db_insert($leieobjekt_latin[$i]) . ")";
 
-				$this->db->query($sql2_utf,__LINE__,__FILE__);
+				$this->db->query($sql2_latin,__LINE__,__FILE__);
 				$this->db_boei->query($sql2_latin,__LINE__,__FILE__);
 
 				$leieobjekt_msg[]=$leieobjekt_utf[$i]['location_code'];
@@ -581,9 +587,10 @@
 		//	$this->db->transaction_commit();
 		//	$this->db_boei->transaction_commit();
 
-			$msg = count($leieobjekt) . ' Leieobjekt er lagt til: ' . @implode(",", $leieobjekt_msg);
+			$msg = count($leieobjekt_latin) . ' Leieobjekt er lagt til: ' . @implode(",", $leieobjekt_msg);
 			$this->receipt['message'][]=array('msg'=> $msg);
-			unset ($leieobjekt);
+			unset ($leieobjekt_latin);
+			unset ($leieobjekt_utf);
 			unset ($leieobjekt_msg);
 			return $msg;
 		}
@@ -635,7 +642,7 @@
 				$sql2_latin = "INSERT INTO fm_tenant (id, first_name, last_name, category, status_eco, status_drift,entry_date,owner_id)"
 					. "VALUES (" . $this->bocommon->validate_db_insert($leietaker_latin[$i]) . ")";
 
-				$this->db->query($sql2_utf,__LINE__,__FILE__);
+				$this->db->query($sql2_latin,__LINE__,__FILE__);
 				$this->db_boei->query($sql2_latin,__LINE__,__FILE__);
 
 				$leietaker_msg[]= '[' .$leietaker_utf[$i]['last_name'] . ', ' . $leietaker_utf[$i]['first_name'] . ']';
@@ -654,7 +661,7 @@
 
 		function oppdater_leieobjekt()
 		{			
-			$sql = " SELECT TOP 100 PERCENT objekt_id,leie_id,leietaker_id, boareal, formaal_id, gateadresse_id, gatenr, etasje,driftsstatus_id"
+			$sql = " SELECT TOP 100 PERCENT objekt_id,leie_id,leietaker_id, boareal, formaal_id, gateadresse_id, gatenr, etasje,driftsstatus_id, flyttenr"
 				. " FROM  v_Leieobjekt"; // WHERE v_Leieobjekt.formaal_id NOT IN (99)";
 
 			$this->db_boei->query($sql,__LINE__,__FILE__);
@@ -672,7 +679,8 @@
 				. " street_id = '" . $this->db_boei->f('gateadresse_id') . "',"
 				. " street_number = '" . $this->bocommon->ascii2utf($this->db_boei->f('gatenr')) . "',"
 				. " driftsstatus_id = '" . $this->db_boei->f('driftsstatus_id') . "',"
-				. " boareal = '" . $this->db_boei->f('boareal') . "'"
+				. " boareal = '" . $this->db_boei->f('boareal') . "',"
+				. " flyttenr = '" . $this->db_boei->f('flyttenr') . "'"
 				. " WHERE  loc1 = '" . $this->db_boei->f('objekt_id') . "'  AND  loc4= '" . $this->db_boei->f('leie_id') . "'";
 				$sql2_latin = " UPDATE  fm_location4 SET "
 				. " tenant_id = '" . $this->db_boei->f('leietaker_id') . "',"
@@ -681,10 +689,11 @@
 				. " street_id = '" . $this->db_boei->f('gateadresse_id') . "',"
 				. " street_number = '" . $this->db_boei->f('gatenr') . "',"
 				. " driftsstatus_id = '" . $this->db_boei->f('driftsstatus_id') . "',"
-				. " boareal = '" . $this->db_boei->f('boareal') . "'"
+				. " boareal = '" . $this->db_boei->f('boareal') . "',"
+				. " flyttenr = '" . $this->db_boei->f('flyttenr') . "'"
 				. " WHERE  loc1 = '" . $this->db_boei->f('objekt_id') . "'  AND  loc4= '" . $this->db_boei->f('leie_id') . "'";
 
-				$this->db->query($sql2_utf,__LINE__,__FILE__);
+				$this->db->query($sql2_latin,__LINE__,__FILE__);
 				$this->db_boei2->query($sql2_latin,__LINE__,__FILE__);
 				$i++;
 			}
@@ -731,7 +740,7 @@
 				. " kostra_id = '" . $this->db_boei->f('tjenestested') . "'"
 				. " WHERE  loc1 = '" . $this->db_boei->f('objekt_id') . "'";
 
-				$this->db->query($sql2_utf,__LINE__,__FILE__);
+				$this->db->query($sql2_latin,__LINE__,__FILE__);
 				$this->db_boei2->query($sql2_latin,__LINE__,__FILE__);
 				$i++;
 			}
@@ -772,8 +781,8 @@
 				. " ant_leieobjekt = '" . $this->db_boei->f('ant_leieobjekt') . "'"
 				. " WHERE  loc1 = '" . $this->db_boei->f('objekt_id') . "'  AND  loc2= '" . $this->db_boei->f('bygg_id') . "'";
 
-				$this->db->query($sql2_utf,__LINE__,__FILE__);
-				$this->db_boei2->query($sql2_utf,__LINE__,__FILE__);
+				$this->db->query($sql2_latin,__LINE__,__FILE__);
+				$this->db_boei2->query($sql2_latin,__LINE__,__FILE__);
 				$i++;
 			}
 		//	$this->db->transaction_commit();
@@ -815,7 +824,7 @@
 				. " ant_leieobjekt = '" . $this->db_boei->f('ant_leieobjekt') . "'"
 				. " WHERE  loc1 = '" . $this->db_boei->f('objekt_id') . "'  AND  loc2= '" . $this->db_boei->f('bygg_id') . "'  AND  loc3= '" . $this->db_boei->f('seksjons_id') . "'";
 
-				$this->db->query($sql2_utf,__LINE__,__FILE__);
+				$this->db->query($sql2_latin,__LINE__,__FILE__);
 				$this->db_boei2->query($sql2_latin,__LINE__,__FILE__);
 				$i++;
 			}
