@@ -8,7 +8,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage setup
- 	* @version $Id: tables_update.inc.php,v 1.66 2007/03/16 14:14:56 sigurdne Exp $
+ 	* @version $Id: tables_update.inc.php,v 1.68 2007/08/12 21:24:41 sigurdne Exp $
 	*/
 
 	/**
@@ -1776,4 +1776,61 @@
 			$GLOBALS['setup_info']['property']['currentver'] = '0.9.17.537';
 			return $GLOBALS['setup_info']['property']['currentver'];
 		}
-	}
\ No newline at end of file
+	}
+
+	/**
+	* Update property version from 0.9.17.537 to 0.9.17.538
+	*/
+
+	$test[] = '0.9.17.537';
+	function property_upgrade0_9_17_537()
+	{
+		$GLOBALS['phpgw_setup']->oProc->m_odb->transaction_begin();
+
+
+		$GLOBALS['phpgw_setup']->oProc->AddColumn('fm_s_agreement_attribute','history',array('type' => 'int','precision' => 2,'nullable' => True));
+
+		$GLOBALS['phpgw_setup']->oProc->CreateTable(
+			'fm_s_agreement_history', array(
+				'fd' => array(
+					'history_id' => array('type' => 'auto','precision' => '4','nullable' => False),
+					'history_record_id' => array('type' => 'int','precision' => '4','nullable' => False),
+					'history_appname' => array('type' => 'varchar','precision' => '64','nullable' => False),
+					'history_detail_id' => array('type' => 'int','precision' => '4','nullable' => False),
+					'history_attrib_id' => array('type' => 'int','precision' => '4','nullable' => False),
+					'history_owner' => array('type' => 'int','precision' => '4','nullable' => False),
+					'history_status' => array('type' => 'char','precision' => '2','nullable' => False),
+					'history_new_value' => array('type' => 'text','nullable' => False),
+					'history_timestamp' => array('type' => 'timestamp','nullable' => False,'default' => 'current_timestamp')
+				),
+				'pk' => array('history_id'),
+				'fk' => array(),
+				'ix' => array(),
+				'uc' => array()
+			)
+		);
+
+		if($GLOBALS['phpgw_setup']->oProc->m_odb->transaction_commit())
+		{
+			$GLOBALS['setup_info']['property']['currentver'] = '0.9.17.538';
+			return $GLOBALS['setup_info']['property']['currentver'];
+		}
+	}
+
+	/**
+	* Update property version from 0.9.17.538 to 0.9.17.539
+	*/
+
+	$test[] = '0.9.17.538';
+	function property_upgrade0_9_17_538()
+	{
+		$GLOBALS['phpgw_setup']->oProc->m_odb->transaction_begin();
+
+		$GLOBALS['phpgw_setup']->oProc->RenameColumn('fm_entity_history','history_entity_attrib_id','history_attrib_id');
+
+		if($GLOBALS['phpgw_setup']->oProc->m_odb->transaction_commit())
+		{
+			$GLOBALS['setup_info']['property']['currentver'] = '0.9.17.539';
+			return $GLOBALS['setup_info']['property']['currentver'];
+		}
+	}
