@@ -5,7 +5,7 @@
 	* @copyright Copyright (C) 2000-2005 Free Software Foundation, Inc. http://www.fsf.org/
 	* @license http://www.gnu.org/licenses/gpl.html GNU General Public License
 	* @package setup
-	* @version $Id: config.php,v 1.1 2007/02/14 14:58:20 sigurdne Exp $
+	* @version $Id: config.php,v 1.2 2007/03/16 21:41:37 sigurdne Exp $
 	*/
 
 	if ( isset($_POST['cancel']) && $_POST['cancel'] )
@@ -261,6 +261,7 @@
 				}
 				break;
 			case 'selected':
+
 				$configs = array();
 				$config  = '';
 				$newvals = explode(' ',$newval);
@@ -270,9 +271,9 @@
 					$configs[] = $newvals[$i];
 				}
 				$config = implode('_',$configs);
-				/* echo $config . '=' . $current_config[$config]; */
+			//	echo $config . '=' . str_replace('-','',$current_config[$config]) . '<br/>';
 				if( isset($current_config[$config])
-					&& $current_config[$config] == $setting)
+					&& str_replace('-','',$current_config[$config]) == $setting)
 				{
 					$setup_tpl->set_var($value,' selected');
 				}
