@@ -8,7 +8,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package sms
 	* @subpackage sms
- 	* @version $Id: set_workorder_status.php,v 1.3 2006/08/21 13:33:27 sigurdne Exp $
+ 	* @version $Id: set_workorder_status.php,v 1.4 2007/03/29 11:27:10 sigurdne Exp $
 	*/
 
 	/**
@@ -18,8 +18,8 @@
 
 	$status_code = array(
 		1 => 'closed',
-		2 => 'no_access',
-		3 => 'open',
+		2 => 'ikke_tilgang',
+		3 => 'i_arbeid',
 	);
 	
 	$param 		= explode(' ' , $command_param);	
